import java.util.ArrayList;
import java.util.Scanner;

public class Domes_John {

	public static final int MAX_DOMES = 100;
	public static final double TOL = 0.000001;

	public static void main(String[] args) {

		int dx, dy, n;
		Scanner in = new Scanner(System.in);
		
		dx = in.nextInt();
		dy = in.nextInt();
		ArrayList<Point> square = new ArrayList<>();
		square.add(new Point(0,0));
		square.add(new Point(0, dy));
		square.add(new Point(dx, dy));
		square.add(new Point(dx, 0));
		n = in.nextInt();
		Point [] locs = new Point[n];
		for(int i=0; i<n; i++) {
			int x = in.nextInt();
			int y = in.nextInt();
			locs[i] = new Point(x, y);
		}
		int [] perm = new int[n];
		for(int i=0; i<n; i++)
			perm[i] = in.nextInt()-1;

		ArrayList<Point> halfPlane = new ArrayList<>();
		Point hp1 = locs[perm[0]];
		halfPlane.add(hp1);
		halfPlane.add(hp1);								// two dummy points to make length = 2
		for(int i=0; i<locs.length; i++) {
			hp1 = locs[perm[i]];
			halfPlane.set(0, hp1);
			for(int j=i+1; j<locs.length; j++) {
				Point hp2 = locs[perm[j]];
				double nx = hp2.y-hp1.y;			// calc normal towards inside
				double ny = hp1.x-hp2.x;
				double c = nx*hp1.x + ny*hp1.y;	// eqn for halfplane line  nx*x + ny*y = c
				double val = (nx*(hp1.x+nx) + ny*(hp1.y+ny) - c);
				double inside = val/Math.abs(val);
				halfPlane.set(1, hp2);
				square = lineClip(halfPlane, inside, square);
				if (square.size() <= 2)
					break;
			}
			if (square.size() <= 2)
				break;
		}
		
		if (square.size() <= 2)
			System.out.println("0");
		else {									// find area
			double area = 0.0;
			Point pprev = square.get(square.size()-1);
			for(Point p : square) {
//System.out.print(p + " ");
				area += (p.x-pprev.x)*(p.y+pprev.y)/2.0;
				pprev = p;
			}
//System.out.println();
			System.out.printf("%.6f\n", area);
		}
	}

	public static void printPoly(ArrayList<Point> poly)
	{
		for(Point p : poly)
			System.out.printf("(%.3f,%.3f) ", p.x, p.y);
		System.out.println();
	}

	public static boolean isZero(double d)
	{
		return (Math.abs(d) <= TOL);
	}

	public static boolean lessThanOrEqual(double d1, double d2)
	{
		return (d1 < d2 || isZero(d1-d2));
	}

	public static boolean between(double a, double b, double c)
	{
		if (b < c)
			return (lessThanOrEqual(b, a) && lessThanOrEqual(a,c));
		else
			return (lessThanOrEqual(c, a) && lessThanOrEqual(a,b));
	}

	public static double dist(Point p1, Point p2)
	{
		double dx = p1.x - p2.x;
		double dy = p1.y - p2.y;
		return Math.sqrt(dx*dx + dy*dy);
	}

	public static ArrayList<Point> lineClip(ArrayList<Point> line, double inside, ArrayList<Point> poly)
	{
		Point p1 = line.get(0);
		Point p2 = line.get(1);
		double a1 = p2.y - p1.y;
		double b1 = p1.x - p2.x;
		double c1 = a1*p1.x + b1*p1.y;		// eqn for first line a1*x + b1*y = c1

		ArrayList<Point> c = new ArrayList<>();
		Point v1 = poly.get(poly.size()-1);
		boolean v1Inside = ((a1*v1.x+b1*v1.y-c1)*inside >= 0);
		for (Point v2 : poly) {
			boolean v2Inside = ((a1*v2.x+b1*v2.y-c1)*inside >= 0);

			if (!v1Inside && v2Inside) {
				Intersection i = lineIntersection(v1, v2, p1, p2);
				if (i.p2 == null)
					c.add(i.p1);
				else
					c.add(i.p2);
				c.add(v2);
			}
			else if (v1Inside && v2Inside)
				c.add(v2);
			else if (v1Inside && !v2Inside) {
				Intersection i = lineIntersection(v1, v2, p1, p2);
				if (i.p2 == null)
					c.add(i.p1);
				else
					c.add(i.p2);
			}
			v1 = v2;
			v1Inside = v2Inside;
		}
		int i=0;
		if (c.size() <= 2)
			return c;
		v1 = c.get(c.size()-1);
		while (i < c.size()) {
			Point v2 = c.get(i);
			if (isZero(v1.x-v2.x) && isZero(v1.y-v2.y)) {
				c.remove(i);
			}
			else {
				v1 = v2;
				i++;
			}
		}
		return c;
	}

	public static Intersection lineIntersection(Point p1, Point p2, Point p3, Point p4)
	{
		double a1 = p2.y - p1.y;
		double b1 = p1.x - p2.x;
		double c1 = a1*p1.x + b1*p1.y;		// eqn for first line a1*x + b1*y = c1
		double a2 = p4.y - p3.y;
		double b2 = p3.x - p4.x;
		double c2 = a2*p3.x + b2*p3.y;		// ditto for second line

		double det = a1*b2 - a2*b1;
		if (isZero(det)) {						// check if parallel
			if (!isZero(a1*p3.x + b1*p3.y - c1))	// check if on same line
				return null;
			else {
				boolean p1Inside = between(p1.x, p3.x, p4.x) && between(p1.y, p3.y, p4.y); 
				boolean p2Inside = between(p2.x, p3.x, p4.x) && between(p2.y, p3.y, p4.y); 
				boolean p3Inside = between(p3.x, p1.x, p2.x) && between(p3.y, p1.y, p2.y); 
				//				boolean p4Inside = between(p4.x, p1.x, p2.x) && between(p4.y, p1.y, p2.y);
				if (p1Inside && p2Inside)
					return new Intersection(p1, p2);
				else if (!p1Inside && p2Inside) {
					if (p3Inside)
						return new Intersection(p3, p2);
					else
						return new Intersection(p4, p2);
				}
				else if (p1Inside && !p2Inside) {
					if (p3Inside)
						return new Intersection(p1, p3);
					else
						return new Intersection(p1, p4);
				}
				else if (dist(p1,p3) < dist(p1, p4))
					return new Intersection(p3, p4);
				else
					return new Intersection(p4, p3);
			}
		}
		else {
			double x = (b2*c1 - b1*c2)/det;
			if (isZero(x - Math.round(x)))
				x = Math.round(x);
			double y = (a1*c2 - a2*c1)/det;
			if (isZero(y - Math.round(y)))
				y = Math.round(y);
			if (between(x, p1.x, p2.x))
				return new Intersection(x, y);
			else if (between(y, p1.y, p2.y))
				return new Intersection(x, y);
			else
				return null;
		}
	}
	
	public static Intersection pointLineDist(Point origin, Point p1, Point p2)
	{
		double vx = p2.x - p1.x;
		double vy = p2.y - p1.y;
		double cx = origin.x - p1.x;
		double cy = origin.y - p1.y;
		double k = (cx*vx + cy*vy)/(vx*vx + vy*vy);
		return new Intersection(p1.x + k*vx, p1.y + k*vy);
	}
}

class Point
{
	public double x, y;

	public Point(double xx, double yy)
	{
		x = xx;
		y = yy;
	}

	public boolean equals(Object o)
	{
		Point p = (Point) o;
		return (p.x == this.x && p.y == this.y);
	}
	
	public String toString()
	{
		return "(" + x + "," + y + ")";
	}
}

class Intersection
{
	Point p1, p2;

	public Intersection(double x, double y)
	{
		p1 = new Point(x, y);
		p2 = null;
	}

	public Intersection(Point pp1, Point pp2)
	{
		p1 = pp1;
		p2 = pp2;
	}
}
