#include <iostream>
#include <iomanip>
#include <cmath>
#include <cassert>
#include <vector>

using namespace std;

using pt = pair<double, double>;

constexpr double EPS = 1e-8;

template<class T1, class T2>
ostream& operator <<(ostream& os, const pair<T1,T2>& x) {
    return os << x.first << ", " << x.second;
}

inline double dist(const pt& a, const pt& b) {
    double dx = a.first - b.first;
    double dy = a.second - b.second;

    return dx * dx + dy * dy;
}

inline double cross(const pt a, const pt b) {
    return a.first * b.second - a.second * b.first;
}

inline double cross(const pt a, const pt b, const pt c) {
    pt v1 = {b.first - a.first, b.second - a.second};
    pt v2 = {c.first - a.first, c.second - a.second};
    return cross(v1, v2);
}

pair<bool, pt> intersect(const pt& a, const pt& b, const pt& c, const pt& d) {
    pt v1 = {b.first - a.first, b.second - a.second};
    pt v2 = {d.first - c.first, d.second - c.second};
    double den = cross(v1, v2);
    if (abs(den) <= EPS) {
        return {false, pt{0.0, 0.0}};
    }
    double p = cross(c, b, d);
    double q = cross(c, d, a);

    return {true, {(a.first * p + b.first * q) / den, (a.second * p + b.second * q) / den}};
}

void clip(vector<pt>& poly, const pt& a, const pt& b) {
    vector<pt> new_poly;

    int n = poly.size();
    for (int i = 0; i < n; ++i) {
        auto& last = poly[(i + n - 1) % n];
        auto& here = poly[i];

        bool side1 = cross(a, b, last) < 0;
        bool side2 = cross(a, b, here) < 0;

        if (side1 != side2) {
            auto res = intersect(last, here, a, b);
            if (res.first)
                new_poly.push_back(res.second);
        }
        if (side2) {
            new_poly.push_back(here);
        }

        /*
        while (new_poly.size() >= 2 and dist(new_poly[new_poly.size() - 2], new_poly.back()) < EPS) {
            new_poly.pop_back();
        }
        */
    }

    /*
    while (new_poly.size() >= 2 and dist(new_poly[0], new_poly.back()) < EPS) {
        new_poly.pop_back();
    }
    */
    swap(poly, new_poly);
}

int main() {
    int w, h, n;
    cin >> w >> h >> n;

    vector<pt> domes(n);
    for (int i = 0; i < n; ++i) {
        cin >> domes[i].first >> domes[i].second;
    }

    vector<int> p(n);

    vector<pt> poly;
    poly.emplace_back(0, 0);
    poly.emplace_back(w, 0);
    poly.emplace_back(w, h);
    poly.emplace_back(0, h);

    /*
    for (auto& pp : poly) {
        cout << pp.first << ", " << pp.second << '\n';
    }
    cout << '\n';
    */

    for (int i = 0; i < n; ++i) {
        cin >> p[i];
        --p[i];
        pt& b = domes[p[i]];
        for (int j = 0; j < i; ++j) {
            pt& a = domes[p[j]];
            clip(poly, a, b);

            /*
            cout << "after clipping by " << a << " " << b << '\n';
            for (auto& pp : poly) {
                cout << pp.first << ", " << pp.second << '\n';
            }
            cout << '\n';
            */
        }
    }

    int m = poly.size();
    double ans = 0.0;
    for (int i = 0; m > 2 and i < m; ++i) {
        int j = (i + 1) % m;
        ans += cross(poly[i], poly[j]);
    }

    ans /= 2.0;

    if (ans < EPS)
        cout << "0\n";
    else
        cout << fixed << setprecision(15) << ans << '\n';

    return 0;
}
