import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Random;

/**
 * ICPC World Finals 2020
 * Input data generator: Landscape
 * 
 * @author Martin Kacer
 */
public class LandscapeGeneratorMK {
	File DIR_TARGET = new File("data/secret/");
	PrintWriter data;
	int counter = 0;

	final Random RAND = new Random(2943915001764L);
	final int MAX = 200000;
	
	void open(String name) throws IOException {
		if (data != null) data.close();
		data = new PrintWriter(new File(DIR_TARGET, "landscape-" + name + ".in"));
	}
	void close() throws IOException { data.close(); data = null; }
	
	public static void main(String[] args) throws Exception {
		LandscapeGeneratorMK inst = new LandscapeGeneratorMK();
		if (args.length > 0) inst.DIR_TARGET = new File(args[0]);
		inst.generateAll();
		if (inst.data != null) inst.close();
	}
	
	void genMinimal(int size, int a, int b) throws Exception {
		String prefix = "01-min-" + size + "x" + a + "-" + b + "-";
		for (char op : "RDHV".toCharArray()) {
			open(prefix + op);
			data.println(size + " 1");
			data.println(op + " " + a + " " + b);
		}
	}
	
	void genRandom(String idx, int n, int k, String ops) throws Exception {
		open(idx + "-random-" + n + "-" + k);
		data.println(n + " " + k);
		for (int i = 0; i < k; ++i) {
			int b = RAND.nextInt(n);
			int a = RAND.nextInt(b+1);
			data.println(ops.charAt(RAND.nextInt(ops.length())) + " " + (a+1) + " " + (b+1));
		}
	}

	void generateAll() throws Exception {
		// minimal cases
		genMinimal(1, 1, 1);
		genMinimal(2, 1, 1);
		genMinimal(2, 2, 2);
		genMinimal(2, 1, 2);
		genMinimal(3, 1, 1);
		genMinimal(3, 1, 2);
		genMinimal(3, 1, 3);
		genMinimal(3, 2, 2);
		genMinimal(3, 2, 3);
		
		// biggest possible mountain
		open("02-max-mountain");
		data.println(MAX + " " + MAX);
		for (int i = 0; i < MAX; ++i)
			data.println("H 1 " + MAX);
		
		// deepest possible valley
		open("03-max-valley");
		data.println(MAX + " " + MAX);
		for (int i = 0; i < MAX; ++i)
			data.println("V 1 " + MAX);
		
		// random test cases
		genRandom("04", 5, 10, "RDVH");
		genRandom("05", 5, 20, "RDVH");
		genRandom("06", 10, 10, "RDVH");
		genRandom("07", 10, 20, "RDVH");
		genRandom("08", 10, 30, "VH");
		genRandom("09", 42, 42, "RDVH");
		for (int i = 0; i < 15; ++i) {
			genRandom(String.valueOf(10+i), RAND.nextInt(10000), RAND.nextInt(1000), "RDVH");
		}
		genRandom("25", MAX, MAX, "RDVH");
		genRandom("26", 1000, MAX, "RDVH");
	}
}
