const int MAX_N = 2000;
const int MAX_COORD = 1000000000;
const double pi = 2.0*acos(0.0);
typedef long long Z;

struct point {
    Z x, y;
    point(Z x=0, Z y=0): x(x), y(y) {}
    point operator-() const { return point(-x, -y); }
    point operator-(const point &p) const { return point(x-p.x, y-p.y); }
    Z cross(const point &p) const { return x*p.y - y*p.x; }
    double theta() const { return atan2(y, x); }
    double dist() const { return sqrt(x*x + y*y); }
    bool operator==(const point &p) const { return x == p.x && y == p.y; }
    bool operator<(const point &p) const {
        return cross(p) < 0;
    }
};

double angle_mod(double v) {
    if (v < -pi) v += 2*pi;
    if (v > pi) v-= 2*pi;
    return v;
}

int solve(const vector<point> &P, double t) {
    int n = P.size();
    int ans = 0;
    for (auto c: P) {
        vector<pair<double,int>> E;
        vector<int> status(n+1, -1);
        int x = 0;
        for (int i = 1; i <= n; ++i) {
            if (P[i-1] == c) { ++x; continue; }
            auto q = P[i-1]-c;
            double u = q.theta(), d = q.dist();
            E.push_back(make_pair(u, -i));
            E.push_back(make_pair(angle_mod(u+pi), i));
            if (d > t) {
                double v = asin(t/d);
                E.push_back(make_pair(angle_mod(u-v), i));
                E.push_back(make_pair(angle_mod(u+pi+v), -i));
            }
        }
        sort(E.begin(), E.end());
        for (int i = 0; i < 2; ++i)
            for (auto &e: E) {
                int i = abs(e.second), delta = e.second > 0 ? 1 : -1;
                if (status[i] != delta) {
                    x += delta;
                    status[i] = delta;
                }
                ans = max(ans, x);
            }
    }
    return ans;
}

bool is_valid(vector<point> &P, Z t) {
    if (P.size() < 3 || P.size() > MAX_N) return false;
    if (t < 1 || t > MAX_COORD) return false;
    int n = P.size();
    for (int i = 0; i < n; ++i) {
        vector<point> z;
        if (P[i].x < -MAX_COORD || P[i].x > MAX_COORD ||
            P[i].y < -MAX_COORD || P[i].y > MAX_COORD) return false;
        for (int j = 0; j < i; ++j) {
            auto d = P[j]-P[i];
            if (d.x == 0 && d.y == 0) {
                fprintf(stderr, "eq pts\n");
                return false;
            }
            if (d.y < 0 || (d.y == 0 && d.x < 0)) d = -d;
            z.push_back(d);
        }
        sort(z.begin(), z.end());
        for (size_t j = 1; j < z.size(); ++j)
            if (!(z[j-1] < z[j])) {
                fprintf(stderr, "collinear points\n");
                return false;
            }
    }
    int a0 = solve(P, t/(1+1e-10));
    int a1 = solve(P, t*(1+1e-10));
    if (a0 != a1) {
        fprintf(stderr, "a0 = %d a1 = %d\n", a0, a1);
        return false;
    }
    return true;
}
