import java.io.*;
import java.util.*;

// Port of dk-angle.cpp
public class LeyLinesAngle {
    private static final double PI = Math.PI;

    public static void main(String[] args) throws IOException {
        (new LeyLinesAngle()).run();
    }

    private void swap(int[] a, int x, int y) {
        int v = a[x];
        a[x] = a[y];
        a[y] = v;
    }

    private void fastSort(int[] order, double[] key, int l, int r) {
        if (l >= r) {
            return;
        }

        int nxt = l + 1;
        for (int i = l + 1; i < r; ++i) {
            if (key[order[i]] < key[order[l]]) {
                swap(order, i, nxt);
                ++nxt;
            }
        }

        swap(order, l, nxt - 1);

        fastSort(order, key, l, nxt - 1);
        fastSort(order, key, nxt, r);
    }

    private void testSort(int n) {
        int[] order = new int[n];
        double[] key = new double[n];
        for (int i = 0; i < n; ++i) {
            order[i] = i;
            key[i] = Math.random();
        }

        fastSort(order, key, 0, n);

        for (int i = 1; i < n; i++) {
            assert(key[order[i - 1]] < key[order[i]]);
        }
    }

    public void run() throws IOException {
        BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
        StringTokenizer st = new StringTokenizer(br.readLine());
        int n = Integer.parseInt(st.nextToken());
        int t = Integer.parseInt(st.nextToken());

        long[] points = new long[n + n];
        for (int i = 0; i < n; i++) {
            st = new StringTokenizer(br.readLine());
            points[2 * i] = Integer.parseInt(st.nextToken());
            points[2 * i + 1] = Integer.parseInt(st.nextToken());
        }

        int ret = 0;

        double[] ths = new double[4 * n];
        int[] ns = new int[4 * n];
        int[] order = new int[4 * n];
        boolean[] added = new boolean[4 * n];
        boolean[] used = new boolean[n];

        for (int i = 0; i < n; i++) {
            int p = 0;
            for (int j = 0; j < n; j++) {
                if (i == j) continue;

                long x1 = points[2 * i];
                long y1 = points[2 * i + 1];
                long x2 = points[2 * j];
                long y2 = points[2 * j + 1];

                long dx = x1 - x2;
                long dy = y1 - y2;

                double th = Math.atan2(dy, dx);
                double ln = Math.hypot(dx, dy);

                if (ln <= t) {
                    ths[p] = (3 * PI + th) % (2 * PI);
                    ns[p] = j;
                    added[p] = true;
                    order[p] = p;
                    p++;

                    ths[p] = (2 * PI + th) % (2 * PI);
                    ns[p] = j;
                    added[p] = false;
                    order[p] = p;
                    p++;
                } else {
                    double ph = Math.asin(t / ln);
                    ths[p] = (2 * PI + th - ph) % (2 * PI);
                    ns[p] = j;
                    added[p] = true;
                    order[p] = p;
                    p++;

                    ths[p] = (2 * PI + th     ) % (2 * PI);
                    ns[p] = j;
                    added[p] = false;
                    order[p] = p;
                    p++;

                    ths[p] = (3 * PI + th     ) % (2 * PI);
                    ns[p] = j;
                    added[p] = true;
                    order[p] = p;
                    p++;

                    ths[p] = (3 * PI + th + ph) % (2 * PI);
                    ns[p] = j;
                    added[p] = false;
                    order[p] = p;
                    p++;
                }
            }

            fastSort(order, ths, 0, p);
            Arrays.fill(used, false);
            int cur = 1;
            for (int rep = 0; rep < 2; rep++) {
                for (int k = 0; k < p; ++k) {
                    int idx = order[k];
                    // System.err.printf("%d %.6f %d %b%n", idx, ths[idx], ns[idx], added[idx]);
                    if (added[idx] && !used[ns[idx]]) {
                        used[ns[idx]] = true;
                        cur++;
                        ret = Math.max(ret, cur);
                    }

                    if (!added[idx] && used[ns[idx]]) {
                        used[ns[idx]] = false;
                        cur--;
                    }
                }
            }
        }

        System.out.println(ret);
    }
}
