// TODO: check whether the edges of the line are included

#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using pnt = complex<ll>;

static ll dot(const pnt &a, const pnt &b)
{
    return real(conj(a) * b);
}

static ll len2(const pnt &a)
{
    return dot(a, a);
}

static ll cross(const pnt &a, const pnt &b)
{
    return imag(conj(a) * b);
}

static ll cross(const pnt &a, const pnt &b, const pnt &c)
{
    return cross(b - a, c - a);
}

class CompareAngle
{
public:
    bool operator()(const pnt &da, const pnt &db) const
    {
        bool fa = da.imag() > 0 || (da.imag() == 0 && da.real() >= 0);
        bool fb = db.imag() > 0 || (db.imag() == 0 && db.real() >= 0);
        if (fa != fb)
            return fa;
        else
        {
            auto c = cross(da, db);
            if (c != 0)
                return c > 0;
            else
                return dot(da, da) < dot(db, db);
        }
    }
};

// Sort by Y then by X
class CompareY
{
public:
    template<typename T>
    bool operator()(const std::complex<T> &a, const std::complex<T> &b) const
    {
        if (a.imag() != b.imag())
            return a.imag() < b.imag();
        else
            return a.real() < b.real();
    }
};

using event = array<int, 2>;

static bool within(const pnt &a, const pnt &b, const pnt &c, ll T)
{
    __int128 limit = __int128(T * T) * len2(b - a);
    ll area = cross(a, b, c);
    __int128 area2 = __int128(area) * area;
    assert(area >= 0);
    return area >= 0 && area2 <= limit;
}

int main()
{
    ios::sync_with_stdio(false);
    int N;
    ll T;
    cin >> N >> T;
    vector<pnt> pnts;
    for (int i = 0; i < N; i++)
    {
        int x, y;
        cin >> x >> y;
        pnts.emplace_back(x, y);
    }
    sort(pnts.begin(), pnts.end(), CompareY());
    vector<int> order(N);
    vector<int> pos(N);
    for (int i = 0; i < N; i++)
    {
        order[i] = i;
        pos[i] = i;
    }

    vector<event> events;
    events.reserve(N * (N - 1) / 2);
    for (int i = 0; i < N; i++)
        for (int j = i + 1; j < N; j++)
            events.push_back(event{{i, j}});
    auto cmp_event = [&](const event &a, const event &b)
    {
        return CompareAngle()(pnts[a[1]] - pnts[a[0]], pnts[b[1]] - pnts[b[0]]);
    };
    sort(events.begin(), events.end(), cmp_event);

    int ans = 2;
    for (const event &e : events)
    {
        int p0 = pos[e[0]];
        int p1 = pos[e[1]];
        assert(p1 == p0 + 1);
        while (p0 + ans < N && within(pnts[e[0]], pnts[e[1]], pnts[order[p0 + ans]], T))
            ans++;
        while (p1 - ans >= 0 && within(pnts[e[1]], pnts[e[0]], pnts[order[p1 - ans]], T))
            ans++;
        swap(order[p0], order[p1]);
        swap(pos[e[0]], pos[e[1]]);
    }
    cout << ans << '\n';
    return 0;
}
