#include <algorithm>
#include <cmath>
#include <iostream>
#include <vector>
using namespace std;

struct Point {
  long double x, y;
  Point(long double x = 0.0, long double y = 0.0) : x(x), y(y) {}
  Point operator+(const Point& p) const { return {x+p.x, y+p.y}; }
  Point operator-(const Point& p) const { return {x-p.x, y-p.y}; }
  Point operator-() const { return {-x, -y}; }
  Point& operator*=(long double c) { x *= c; y *= c; return *this; }
  long double Len() const { return hypot(x, y); }
};

// Positive if b points counterclockwise of a.
inline long double CrossProd(const Point& a, const Point& b) {
  return a.x*b.y - a.y*b.x;
}

// Efficiently compares points by angle, in the range (-PI,PI], using cross products only.
bool AngleCmp(const Point& a, const Point& b) {
  bool aupper = (a.y > 0.0 || (a.y == 0.0 && a.x < 0.0));
  bool bupper = (b.y > 0.0 || (b.y == 0.0 && b.x < 0.0));
  if (aupper != bupper) return bupper;
  return CrossProd(a, b) > 0;
}

struct Event {
  Point p;
  int n;
  bool added;

  bool operator<(const Event& e) { return AngleCmp(p, e.p); }
};

int main() {
  int N, T;
  while (cin >> N >> T) {
    vector<Point> P(N);
    for (auto& p : P) cin >> p.x >> p.y;

    int ret = 0;
    for (int i = 0; i < P.size(); i++) {
      vector<Event> ev;
      for (int j = 0; j < P.size(); j++) if (j != i) {
        Point v = P[j]-P[i];
        long double ln = v.Len();
        if (ln <= T) {
          ev.push_back(Event{-v, j, true });
          ev.push_back(Event{ v, j, false});
        } else {
          long double d = sqrt(ln*ln - T*T);
          Point v2{T*v.x - d*v.y, T*v.y + d*v.x};
          Point v3{T*v.x + d*v.y, T*v.y - d*v.x};
          v2 *= T/ln/ln;
          v3 *= T/ln/ln;
          ev.push_back(Event{ v - v2, j, true });
          ev.push_back(Event{ v     , j, false});
          ev.push_back(Event{-v     , j, true });
          ev.push_back(Event{-v + v3, j, false});
        }
      }

      sort(ev.begin(), ev.end());
      vector<bool> used(N);
      int cur = 1;
//cout << P[i].x << ',' << P[i].y << endl;
      for (int rep = 0; rep < 2; rep++)
      for (auto const& e : ev) {
//cout << "  " << e.p.x << ',' << e.p.y << "  " << (e.added ? '+' : '-') << e.n;
//cout << "  " << CrossProd(e.p, P[e.n]-P[i]) / e.p.Len() << endl;
        if (e.added && !used[e.n]) {
          used[e.n] = true;
          cur++;
          ret = max(ret, cur);
        }
        if (!e.added && used[e.n]) {
          used[e.n] = false;
          cur--;
        }
      }
    }
    cout << ret << endl;
  }
}


