#include <stdio.h>
#include <algorithm>
#include <vector>

using std::max;
using std::vector;

struct Phone { unsigned int x, y, z; };

vector<Phone> phones;
int n;

bool read_data() {
  if (scanf("%d", &n) != 1) return false;
  phones.resize(n);
  for (Phone &p : phones) {
    if (scanf("%u %u %u", &p.x, &p.y, &p.z) != 3) return false;
  }
  return true;
}

unsigned int dist(const Phone &a, const Phone &b,
                  bool dim_x = true, bool dim_y = true, bool dim_z = true) {
  unsigned int d = 0;
  if (dim_x && b.x > a.x) d += b.x - a.x;
  if (dim_y && b.y > a.y) d += b.y - a.y;
  if (dim_z && b.z > a.z) d += b.z - a.z;
  return d;
}

void process_data() {
  const Phone zero = { 0, 0, 0 };
  unsigned int max_sum[7] = { 0, 0, 0, 0, 0, 0, 0 };
  int best_index[7] = { 0, 0, 0, 0, 0, 0, 0 };
  unsigned int d;
  for (int i = 0; i < n; ++i) {
    const Phone &p = phones[i];
    d = dist(zero, p, true, false, false); if (d > max_sum[0]) { max_sum[0] = d; best_index[0] = i; }
    d = dist(zero, p, false, true, false); if (d > max_sum[1]) { max_sum[1] = d; best_index[1] = i; }
    d = dist(zero, p, false, false, true); if (d > max_sum[2]) { max_sum[2] = d; best_index[2] = i; }
    d = dist(zero, p, true, true, false);  if (d > max_sum[3]) { max_sum[3] = d; best_index[3] = i; }
    d = dist(zero, p, true, false, true);  if (d > max_sum[4]) { max_sum[4] = d; best_index[4] = i; }
    d = dist(zero, p, false, true, true);  if (d > max_sum[5]) { max_sum[5] = d; best_index[5] = i; }
    d = dist(zero, p, true, true, true);   if (d > max_sum[6]) { max_sum[6] = d; best_index[6] = i; }
  }

  unsigned int min_cost = -1;
  int min_cost_index = -1;

  for (int i = 0; i < n; ++i) {
    const Phone &p = phones[i];
    d = 0;
    for (int j = 0; j < 7; ++j) {
      d = max(d, dist(p, phones[best_index[j]]));
      if (d >= min_cost) break;
    }
    if (d < min_cost) {
      min_cost = d;
      min_cost_index = i;
    }
  }
  printf("%u %d\n", min_cost, min_cost_index + 1);
}

int main() {
  while (read_data()) process_data();
  return 0;
}
