#include <inttypes.h>
#include <stdio.h>
#include <algorithm>
#include <vector>

using std::max;
using std::swap;
using std::vector;

typedef int64_t int64;

struct Phone { int64 x, y, z; };

vector<Phone> phones;
int n;

bool read_data() {
  if (scanf("%d", &n) != 1) return false;
  phones.resize(n);
  for (Phone &p : phones) {
    if (scanf("%ld %ld %ld", &p.x, &p.y, &p.z) != 3) return false;
  }
  return true;
}

int64 dist(const Phone &a, const Phone &b) {
  return max(b.x - a.x, 0L) +
    max(b.y - a.y, 0L) +
    max(b.z - a.z, 0L);
}

void process_data() {
  vector<int> perm;
  for (int i = 0; i < n; ++i) perm.push_back(i);
  for (int i = n-1; i > 0; --i) {
    const int other = (int)(drand48() * (i+1));
    if (other != i) swap(perm[i], perm[other]);
  }

  int64 min_cost = 1LL<<40;
  int min_cost_index = -1;
  for (int i = 0; i < n; ++i) {
    const Phone &p = phones[perm[i]];
    int64 d = 0;
    for (int j = 0; j < n; ++j) {
      const Phone &p2 = phones[perm[j]];
      d = max(d, dist(p, p2));
      if (d > min_cost || (d == min_cost && perm[i] > min_cost_index)) break;
    }
    if (d < min_cost || (d == min_cost && perm[i] < min_cost_index)) {
      min_cost = d;
      min_cost_index = perm[i];
    }
  }
  printf("%ld %d\n", min_cost, min_cost_index + 1);
}

int main() {
  while (read_data()) process_data();
  return 0;
}
