/* A much more complicated solution, that first solves the problem
 * independently for each latitude (producing a phase shift and a period)
 * and then combines these results across latitudes. This is done mainly
 * so that various bugs can be introduced to verify test data coverage.
 */

#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using pii = pair<int, int>;
using vi = vector<int>;

static constexpr int SCALE = 10000;

// Undefined sign for negative inputs
template<typename T> static constexpr T gcd(T a, T b) { return b ? gcd(b, a % b) : a; }
template<typename T> static constexpr T wrap_pos(T a, T m) { return a < 0 ? a + m : a; }
template<typename T> static constexpr T sqr(T a) { return a * a; }
// m must be positive
template<typename T> static constexpr T mod(T a, T m) { return wrap_pos(a % m, m); }

template<typename T>
static constexpr T inverse2(T a, T m) { return a <= 1 ? a : mod((1 - inverse2(m % a, a) * m) / a, m); }

// a must be relatively prime to m, m > 0
template<typename T>
static constexpr T inverse(T a, T m) { return inverse2(mod(a, m), m); }

static int load_coord()
{
    double x;
    cin >> x;
    return int(round(x * SCALE));
}

static vector<vi> load_map(int N)
{
    vector<vi> ans(180 * SCALE);
    for (int i = 0; i < N; i++)
    {
        int lat = load_coord() + 90 * SCALE;
        int lon = load_coord();
        ans[lat].push_back(lon);
    }
    for (vi &row : ans)
        sort(row.begin(), row.end());
    return ans;
}

static vi relative(const vi &x)
{
    int N = x.size();
    int last = x.back() - 360 * SCALE;
    vi a(N);
    for (int i = 0; i < N; i++)
    {
        a[i] = x[i] - last;
        last = x[i];
    }
    return a;
}

static pii solve1(const vi &x, const vi &y)
{
    if (x.size() != y.size())
        return {-1, -1};
    int N = x.size();
    vi a = relative(x);
    vi b = relative(y);
    vi fail(N + 1);
    fail[0] = -1;
    for (int i = 1; i <= N; i++)
    {
        int s = a[i - 1];
        int f = fail[i - 1];
        while (f >= 0 && a[f] != s)
            f = fail[f];
        fail[i] = f + 1;
    }
    int m = 0;
    int first = INT_MIN;
    for (int i = 0; i < 3 * N; i++)
    {
        int s = b[i % N];
        while (m >= 0 && a[m] != s)
            m = fail[m];
        m++;
        if (m == N)
        {
            int pos = y[i % N] + (i / N) * 360 * SCALE - x[N - 1];
            if (first == INT_MIN)
                first = pos;
            else
            {
                int period = pos - first;
                first = mod(first, period);
                assert(360 * SCALE % period == 0);
                return {first, period};
            }
            m = fail[m];
        }
    }
    return {-1, -1};
}

[[noreturn]] static void different()
{
    cout << "Different\n";
    exit(0);
}

// Solve x = a (mod s) and x = b (mod t)
// Returns -1, -1 if no solutions exist
static pair<ll, ll> crt(ll a, ll s, ll b, ll t)
{
    assert(0 <= a && a < s);
    assert(0 <= b && b < t);
    ll g = gcd(s, t);
    if (g > 1)
    {
        if (a % g != b % g)
            return {-1, -1};
        ll c, m;
        tie(c, m) = crt(a / g, s / g, b / g, t / g);
        assert(m > 0);
        return {c * g + a % g, m * g};
    }
    else
    {
        ll p = s * t;
        ll u = inverse(s, t) * s % p;
        ll v = inverse(t, s) * t % p;
        return {(b * u + a * v) % p, p};
    }
}

int main()
{
    ios::sync_with_stdio(false);
    int N;
    cin >> N;
    vector<vi> map1 = load_map(N);
    vector<vi> map2 = load_map(N);
    int phase = 0;
    int period = 1;
    for (size_t i = 0; i < map1.size(); i++)
    {
        if (map1[i].empty() && map2[i].empty())
            continue;
        int p, q;
        tie(p, q) = solve1(map1[i], map2[i]);
        if (q < 0)
            different();
        // cerr << "In " << phase << ' ' << period << ' ' << p << ' ' << q << '\n';
        tie(phase, period) = crt(phase, period, p, q);
        // cerr << "Out " << phase << ' ' << period << '\n';
        if (period < 0)
            different();
    }
    cout << "Same\n";

    return 0;
}
