#include <assert.h>
#include <math.h>
#include <stdio.h>
#include <algorithm>
#include <vector>

using namespace std;

class Point {
public:
  int lat, lng;
  bool operator==(const Point &other) const {
    return lat == other.lat && lng == other.lng;
  }
  bool operator!=(const Point &other) const { return !(*this == other); }
};

vector<Point> a, b;
int n;

bool read_data() {
  if (scanf("%d", &n) != 1) return false;
  double lat, lng;
  a.resize(n);
  b.resize(n);
  for (int i = 0; i < n; ++i) {
    assert(scanf("%lf %lf", &lat, &lng) == 2);
    a[i].lat = round(10000.0 * lat); a[i].lng = round(10000.0 * lng);
  }
  for (int i = 0; i < n; ++i) {
    assert(scanf("%lf %lf", &lat, &lng) == 2);
    b[i].lat = round(10000.0 * lat); b[i].lng = round(10000.0 * lng);
  }
  return true;
}

void sort_points(vector<Point> *v) {
  sort(v->begin(), v->end(), [](const Point &p, const Point &q) {
      if (p.lng != q.lng) return p.lng < q.lng;
      return p.lat < q.lat;
    });
}

void compute_delta(const vector<Point> &v, vector<Point> *delta) {
  for (int i = 0; i < n; ++i) {
    int d = v[(i+1)%n].lng - v[i].lng;
    while (d < 0) d += 3600000;
    while (d >= 3600000) d -= 3600000;
    delta->push_back({ v[i].lat, d });
  }
}

// https://en.wikipedia.org/wiki/Knuth–Morris–Pratt_algorithm
bool is_substring(const vector<Point> &w, const vector<Point> &s) {
  // Precompute table
  vector<int> t;
  t.resize(w.size()+1);
  int pos = 1;
  int cnd = 0;
  t[0] = -1;
  while (pos < (int)w.size()) {
    if (w[pos] == w[cnd]) {
      t[pos] = t[cnd];
    } else {
      t[pos] = cnd;
      cnd = t[cnd];
      while (cnd >= 0 && w[pos] != w[cnd]) {
        cnd = t[cnd];
      }
    }
    ++pos;
    ++cnd;
  }
  t[pos] = cnd;

  int j = 0, k = 0;
  while (j < (int)s.size()) {
    if (w[k] == s[j]) {
      ++j;
      ++k;
      if (k == (int)w.size()) {
        // occurrence found
        return true;
      }
    } else {
      k = t[k];
      if (k < 0) {
        ++j;
        ++k;
      }
    }
  }
  return false;
}

bool congruent() {
  if (n == 1) {
    return a[0].lat == b[0].lat;
  }
  sort_points(&a);
  sort_points(&b);
  vector<Point> s, w;
  compute_delta(a, &s);
  compute_delta(a, &s);
  compute_delta(b, &w);
  return is_substring(w, s);
}

int main() {
  while (read_data()) {
    if (congruent()) {
      printf("Same\n");
    } else {
      printf("Different\n");
    }
  }
  return 0;
}
