#include <cstdio>
#include <vector>
#include <algorithm>
#include <map>
#include <set>

using namespace std;

#define MAXN 800100
#define FULLCIRCLE 3600000

int counts[MAXN];
int revpos1[MAXN];
int reorder[MAXN];
int result[MAXN];

void rebalance(vector<int> &T, int N, int skip) {
  for (int i = 0; i < skip; ++i) T[N+i] = T[i];
  for (int i = 0; i < N; ++i) counts[i] =  0;
  for (int i = 0; i < N; ++i) counts[T[i]] += 1;
  for (int i = 1; i < N; ++i) counts[i] += counts[i-1];
  for (int i = N-1; i >= 0; --i) revpos1[--counts[T[i+skip]]] = i;
  for (int i = 0; i < N; ++i) counts[i] = 0;
  for (int i = 0; i < N; ++i) counts[T[i]] += 1;
  for (int i = 1; i < N; ++i) counts[i] += counts[i-1];
  for (int i = N-1; i >= 0; --i) reorder[--counts[T[revpos1[i]]]] = revpos1[i];
  int cv0 = -1;
  int cv1 = -1;
  int cur = -1;
  for (int i = 0; i < N; ++i) {
    if (T[reorder[i]] != cv0 || T[reorder[i] + skip] != cv1) {
      cv0 = T[reorder[i]];
      cv1 = T[reorder[i] + skip];
      cur += 1;
    }
    result[reorder[i]] = cur;
  }
  for (int i = 0; i < N; ++i) T[i] = result[i];
}

void full_rebalance(vector<int> &T, int N) {
  int skip = 1;
  while (skip < N) {
    rebalance(T, N, skip);
    skip *= 2;
  }
}

vector<int> toDiffs(vector<int> &A) {
  sort(A.begin(), A.end());
  int N = A.size();
  vector<int> res(N);
  for (int i = 0; i < N - 1; ++i) res[i] = A[i+1] - A[i];
  res[N - 1] = A[0] + FULLCIRCLE - A[N - 1];
  vector<int> cres = res;
  sort(cres.begin(), cres.end());
  map<int, int> conv;
  for (int i = 0; i < N; ++i) conv[cres[i]] = i;
  for (int i = 0; i < N; ++i) res[i] = conv[res[i]];
  res.resize(2 * N);
  full_rebalance(res, N);
  for (int i = 0; i < N; ++i) res[i + N] = res[i];
  return res;
}

// Returns all possible values v such that B + v = A. Returns them as non-negative numbers
// smaller than FULLCIRCLE.
vector<int> compare(vector<int> &A, vector<int> &B) {
  if (A.size() != B.size()) return vector<int>();
  int N = A.size();
  vector<int> Adiffs = toDiffs(A);
  vector<int> Bdiffs = toDiffs(B);
  int A0 = 0, B0;
  for (int i = 0; i < N; ++i) if (Adiffs[i] == 0) A0 = i;
  for (int i = 0; i < N; ++i) if (Bdiffs[i] == 0) B0 = i;
  int delta = A[A0] - B[B0];
  for (int i = 0; i < N; ++i) {
    if ((A[(A0 + i) % N] - B[(B0 + i) % N] - delta + 2 * FULLCIRCLE) % FULLCIRCLE) {
      return vector<int>();
    }
  }
  vector<int> res;
  for (int i = 0; i < N; ++i) {
    if (Bdiffs[i] == 0) {
      int cand = A[A0] - B[i];
      while (cand < 0) cand += FULLCIRCLE;
      cand %= FULLCIRCLE;
      res.push_back(cand);
    }
  }
  sort(res.begin(), res.end());
  return res;
}

void scan(map<int, vector<int>> &M, int N) {
  for (int i = 0; i < N; ++i) {
    double lat, lon;
    scanf("%lf %lf", &lat, &lon);
    int ilat = (90 + lat) * 10000 + 0.5;
    int ilon = (180 + lon) * 10000 + 0.5;
    if (M.find(ilat) == M.end()) {
      M[ilat] = vector<int>();
    }
    M[ilat].push_back(ilon);
  }
}

bool run() {
  map<int, vector<int>> A;
  map<int, vector<int>> B;
  int N;
  scanf("%d", &N);
  scan(A, N);
  scan(B, N);
  vector<int> turns;
  vector<int>::iterator turns_end = turns.begin();
  for (auto &latveclon : A) {
    if (B.find(latveclon.first) == B.end()) {
      return false;
    }
    vector<int> newturns = compare(latveclon.second, B[latveclon.first]);
    if (turns.begin() == turns_end) {
      turns = newturns;
      turns_end = turns.end();
    } else {
      vector<int> cturns(turns.begin(), turns_end);
      turns_end = set_intersection(newturns.begin(), newturns.end(), cturns.begin(),
                                   cturns.end(), turns.begin());
      turns.resize(turns_end - turns.begin());
    }
    if (turns.begin() == turns_end) {
      return false;
    }
  }
  return true;
}

int main() {
  printf("%s\n", run() ? "Same" : "Different");
  return 0;
}
