// Solution: For each latitude, group the longitude points together.
// Compare the "derivative" (distances between sorted points) for each latitude
// and ensure they are equal
//
// If so, compute the possible shifts for each latitude (O(n) of them).
// Intersect all sets of shifts in O(n) time to see if possible or not. BUG:
// not all shifts are valid, but this assumes they all are.
//
// Complexity: O(n log n) due to map and set
#include <bits/stdc++.h>

using namespace std;

constexpr int SCALE = 10000;
constexpr int TOTAL = 360 * SCALE;
map<int, vector<int>> points[2], diffs[2];

int read(int base) {
    double d;
    cin >> d;
    d *= SCALE;
    d += base;
    return d + 0.5;
}

// O(n) min rotation point
int min_rotation(const vector<int>& v) {
    int a = 0;
    int n = v.size();
    for (int b = 0; b < n; ++b) {
        for (int i = 0; i < n; ++i) {
            int x = a + i >= n ? a + i - n : a + i;
            int y = b + i >= n ? b + i - n : b + i;
            if (a + i == b or v[x] < v[y]) {
                b += max(0, i - 1);
                break;
            }

            if (v[x] > v[y]) {
                a = b;
                break;
            }
        }
    }

    return a;
}

// Take the "derivative" of v
vector<int> diff(const vector<int>& v) {
    if (v.size() <= 1) {
        return {};
    }

    vector<int> res = {v[0] + TOTAL - v.back()};
    for (int i = 1; i < v.size(); ++i) {
        res.push_back(v[i] - v[i - 1]);
    }

    rotate(begin(res), begin(res) + min_rotation(res), end(res));

    return res;
}

set<int> get_shifts(const vector<int>& v, int x) {
    set<int> s;
    for (int y : v) {
        int d = x - y;
        if (d < 0) {
            d += TOTAL;
        }

        s.insert(d);
    }

    return s;
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0); cout.tie(0);

    int n;
    cin >> n;
    vector<int> lats;
    for (int k = 0; k < 2; ++k) {
        for (int i = 0; i < n; ++i) {
            int a = read(90 * SCALE);
            int b = read(180 * SCALE);

            points[k][a].push_back(b);
        }

        for (auto& p : points[k]) {
            int lat = p.first;
            if (k == 0)
                lats.push_back(lat);
            sort(begin(p.second), end(p.second));
            diffs[k][lat] = diff(p.second);
        }
    }

    bool first = true;
    set<int> valid_shifts;
    bool valid = true;
    for (int lat : lats) {
        if (points[0][lat].size() != points[1][lat].size() or diffs[0][lat] != diffs[1][lat]) {
            valid = false;
            break;
        }

        set<int> s = get_shifts(points[0][lat], points[1][lat][0]);
        if (first) {
            valid_shifts = s;
        } else {
            // Intersection, O(n log n) over the whole program
            set<int> new_valid_shifts;
            for (int x : s) {
                if (valid_shifts.count(x)) {
                    new_valid_shifts.insert(x);
                }
            }

            swap(valid_shifts, new_valid_shifts);
        }

        first = false;
        if (valid_shifts.empty()) {
            valid = false;
            break;
        }
    }

    cout << (valid ? "Same" : "Different") << '\n';

    return 0;
}
