/* Based on by_lat.cpp, but skips the Chinese Remainder Theorem and just says
 * they're the same if the phases are all equal.
 */

#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using pii = pair<int, int>;
using vi = vector<int>;

static constexpr int SCALE = 10000;

static int load_coord()
{
    double x;
    cin >> x;
    return int(round(x * SCALE));
}

static vector<vi> load_map(int N)
{
    vector<vi> ans(180 * SCALE);
    for (int i = 0; i < N; i++)
    {
        int lat = load_coord() + 90 * SCALE;
        int lon = load_coord();
        ans[lat].push_back(lon);
    }
    for (vi &row : ans)
        sort(row.begin(), row.end());
    return ans;
}

static vi relative(const vi &x)
{
    int N = x.size();
    int last = x.back() - 360 * SCALE;
    vi a(N);
    for (int i = 0; i < N; i++)
    {
        a[i] = x[i] - last;
        last = x[i];
    }
    return a;
}

static pii solve1(const vi &x, const vi &y)
{
    if (x.size() != y.size())
        return {-1, -1};
    int N = x.size();
    vi a = relative(x);
    vi b = relative(y);
    vi fail(N + 1);
    fail[0] = -1;
    for (int i = 1; i <= N; i++)
    {
        int s = a[i - 1];
        int f = fail[i - 1];
        while (f >= 0 && a[f] != s)
            f = fail[f];
        fail[i] = f + 1;
    }
    int m = 0;
    int first = INT_MIN;
    for (int i = 0; i < 3 * N; i++)
    {
        int s = b[i % N];
        while (m >= 0 && a[m] != s)
            m = fail[m];
        m++;
        if (m == N)
        {
            int pos = y[i % N] + (i / N) * 360 * SCALE - x[N - 1];
            if (first == INT_MIN)
                first = pos;
            else
            {
                int period = pos - first;
                first %= period;
                if (first < 0)
                    first += period;
                assert(360 * SCALE % period == 0);
                return {first, period};
            }
            m = fail[m];
        }
    }
    return {-1, -1};
}

[[noreturn]] static void different()
{
    cout << "Different\n";
    exit(0);
}

int main()
{
    ios::sync_with_stdio(false);
    int N;
    cin >> N;
    vector<vi> map1 = load_map(N);
    vector<vi> map2 = load_map(N);
    int phase = -1;
    for (size_t i = 0; i < map1.size(); i++)
    {
        if (map1[i].empty() && map2[i].empty())
            continue;
        int p, q;
        tie(p, q) = solve1(map1[i], map2[i]);
        if (q < 0)
            different();
        if (phase == -1)
            phase = p;
        else if (phase != p)
            different();
    }
    cout << "Same\n";

    return 0;
}
