#!/usr/bin/env ruby

require 'set'

class Generator
  def initialize(file_path)
    @file_no = 50
    @file_path = file_path
  end

  def random(n, xvals = nil, missing = 0)
    m1 = Set.new
    n.times do
      x = xvals ? xvals[rand(xvals.count)] : (-900000 + rand(1800000))
      y = -1800000 + rand(3600000)
      next if x <= -900000 || x >= 900000 || y <= -1800000 || y > 1800000
      m1 << [x,y]
    end
    m1 = m1.to_a
    m2 = rotate(m1, rand(3600000)).shuffle
    m1.pop(missing)
    m2.pop(missing)
    output_i(m1, m2, missing == 0)
  end

  def regular(n, missing = 0)
    m1 = n.times.map do |i|
      [ -123456, -1800000 + (3600000/n) * (i+1) ]
    end
    m2 = rotate(m1, rand(3600000)).shuffle
    m1.pop(missing)
    m2.pop(missing)
    output_i(m1, m2, missing < 2)
  end

  def output1(m1)
    output1_i(m1.map { |x,y| [ x*10000, y*10000 ] })
  end

  def output(m1, m2, same)
    output_i(m1.map { |x,y| [ x*10000, y*10000 ] },
             m2.map { |x,y| [ x*10000, y*10000 ] },
             same)
  end

  private

  def rotate(m1, r)
    m1.map do |x,y|
      y2 = y + r
      while y2 <= -1800000 do y2 += 3600000; end
      while y2 > 1800000 do y2 -= 3600000; end
      [x,y2]
    end
  end

  def output1_i(m1)
    r = rand(3600000)
    output_i(m1, rotate(m1, r), true)
  end

  def output_i(m1, m2, same)
    raise 'unequal sizes' if m1.count != m2.count
    raise 'too large' if m1.count > 400000
    raise 'too small' if m1.count < 1
    raise 'not unique' if m1.uniq.count != m1.count
    raise 'not unique' if m2.uniq.count != m2.count
    f = File.open("#{@file_path}/#{'%02d' % @file_no}-matthias.in", 'w')
    f << "#{m1.count}\n"
    m1.shuffle.each do |x,y|
      raise x.to_s if format_check(x)
      raise y.to_s if format_check(y)
      f << "#{format(x)} #{format(y)}\n"
    end
    m2.shuffle.each do |x,y|
      raise x.to_s if format_check(x)
      raise y.to_s if format_check(y)
      f << "#{format(x)} #{format(y)}\n"
    end
    f.close
    File.write("#{@file_path}/#{'%02d' % @file_no}-matthias.ans",
               same ? "Same\n" : "Different\n")
    @file_no += 1
  end

  def format_check(x)
    x/10000.0 != format(x).to_f
  end

  def format(x)
    if x < 0
      sprintf '-%d.%04d', x.abs/10000, (x.abs % 10000)
    else
      sprintf '%d.%04d', x.abs/10000.0, (x.abs % 10000)
    end
  end
end

srand(575468463)
g = Generator.new('data/secret')

# 1 point
g.output1([[0, 0]])
g.output1([[89.9999, 180]])
g.output1([[45, 20]])
g.output1([[-45, 20]])
g.output([[45, 20]], [[-45, 20]], false)

# 2 points
g.output1([[0, 0], [0, 180]])
g.output1([[0, -60], [0, 60]])
g.output([[0, -60], [0, 60]], [[0, -30], [0, 30]], false)
g.output1([[45, 0], [45, 30]])
g.output([[45, 0], [45, 30]], [[45, 0], [45, -30]], true)
g.output([[45, 0], [45, 30]], [[45, 0], [-45, 30]], false)
g.output1([[45, -30], [45, 30]])
g.output([[45, -30], [45, 30]], [[45, -45], [45, 45]], false)
g.output([[45, -30], [45, 30]], [[-45, -30], [45, 30]], false)
g.output1([[-45, -30], [45, 30]])
g.output([[-45, -30], [45, 30]], [[-45, -30], [45, -30]], false)
g.output([[-45, -30], [45, 30]], [[-45, -30], [-45, 30]], false)

g.random(10)
g.random(10, nil, 1)
g.random(1000)
g.random(1000, nil, 1)
g.random(1000, [-60000, -45000, -30000, 0, 30000, 45000, 60000])
g.random(100000)
g.random(100000, nil, 2)
g.random(100000, [-60000, -45000, -30000, 0, 30000, 45000, 60000])
g.random(400000)
g.random(400000, nil, 3)
g.random(400000, [-60000, -45000, -30000, 0, 30000, 45000, 60000])

g.regular(10)
g.regular(10, 1)
g.regular(10, 3)
g.regular(1000)
g.regular(1000, 1)
g.regular(1000, 2)
g.regular(90000)
g.regular(90000, 1)
g.regular(90000, 2)
