#include <iostream>
#include <sstream>
#include <vector>
#include <algorithm>
#include <string>
#include "validate.h"

using namespace std;

static const int MAX_QUERIES = 12;
static const int MAX_LINE = 10000;

static string author_getline(int max_size)
{
    vector<char> storage(max_size + 1);
    author_out.getline(storage.data(), storage.size());
    if (author_out.fail())
        wrong_answer("Error reading line from contestant solution (most likely line too long)");
    auto bytes_read = author_out.gcount();
    // Separator is counted in gcount, but not stored in the string
    if (bytes_read > 0 && !author_out.eof())
        bytes_read--;
    return string(storage.data(), bytes_read);
}

static string sanitise(const string &msg)
{
    /* Ensure that a command is valid UTF-8 so that it doesn't crash problemtools.
     * Rather than try to recognise UTF-8, just strip out anything that isn't
     * printable ASCII. While we're at it, shorten to a decent length.
     */
    string out;
    for (char c : msg)
        if (c >= ' ' && c < 127)
            out += c;
        else
            out += '?';
    if (out.size() > 200)
    {
        out.resize(197);
        out += "...";
    }
    return out;
}

static bool case_equal(const string &a, const string &b)
{
    return equal(
        a.begin(), a.end(), b.begin(), b.end(),
        [](unsigned char x, unsigned char y) { return tolower(x) == tolower(y); }
    );
}

int main(int argc, char **argv)
{
    init_io(argc, argv);
    int T;
    string trash;
    judge_in >> T;
    cout << T << '\n';
    for (int cas = 0; cas < T; cas++)
    {
        int N;
        string state;
        judge_in >> N >> state;
        vector<string> answers(N);
        for (int i = 0; i < N; i++)
            judge_in >> answers[i];

        judge_message("Starting interaction on batch %d (N = %d)\n", cas + 1, N);
        int n_queries = 0;
        vector<int> test(N);
        vector<bool> used(N);
        cout << N << endl;
        while (true)
        {
            string line = author_getline(MAX_LINE);
            istringstream toks(line);
            string command;
            if (!(toks >> command))
                wrong_answer("Could not read command");
            if (case_equal(command, "answer"))
            {
                string answer;
                toks >> answer;
                if (int(answer.size()) != N)
                    wrong_answer("Answer has wrong length (%d, expected %d)",
                                int(answer.size()), N);
                for (int i = 0; i < N; i++)
                    if (answer[i] != '0' && answer[i] != '1')
                        wrong_answer("Answer has incorrect format");
                if (answer != state)
                    wrong_answer("Incorrect answer: %s, expected %s",
                                 answer.c_str(), state.c_str());
                if (toks >> trash)
                    wrong_answer("Trailing garbage on answer line");
                break;
            }
            else if (case_equal(command, "test"))
            {
                if (n_queries >= MAX_QUERIES)
                    wrong_answer("Too many queries");
                n_queries++;
                fill(used.begin(), used.end(), false);
                for (int i = 0; i < N; i++)
                {
                    if (!(toks >> test[i]))
                        wrong_answer("Failed to read element %d for query %d",
                                    i + 1, n_queries);
                    if (test[i] < 0 || test[i] > N)
                        wrong_answer("Query value %d is out of range", test[i]);
                    test[i]--;
                    if (test[i] >= 0)
                    {
                        if (used[test[i]])
                            wrong_answer("Query value %d is used twice", test[i]+1);
                        used[test[i]] = true;
                    }
                }
                if (toks >> trash)
                    wrong_answer("Trailing garbage on test line");

                string result(N, '-');
                for (int i = 0; i < N; i++)
                    if (test[i] >= 0)
                        result[i] = answers[i][test[i]];
                cout << result << endl;
            }
            else
                wrong_answer("Invalid command %s", sanitise(command).c_str());
        }
        judge_message("Correct answer for batch %d\n", cas + 1);
    }
    if (author_out >> trash)
        wrong_answer("Trailing garbage at the end of input");
    judge_message("All batches correct\n");
    accept();
}
