#include <iostream>
#include <fstream>
#include <vector>
#include <bitset>
#include <random>
#include <algorithm>
#include <cassert>

using namespace std;

//#define REPORT_QUERIES
//#define PRE_SHUFFLE

static constexpr int MAXN = 100;

typedef bitset<2 * MAXN> bs;

class state
{
private:
    vector<bs> implies;
    bs known;
    bs all_bad;

public:
    explicit state(int M);
    void add(int x, int y);
    void update();
    bool tested(int x, int y) const;
    int known_count() const { return known.count(); }
    int status(int x) const;
};

state::state(int M) : implies(M)
{
    for (int i = 0; i < M; i++)
        implies[i][i] = true;
    for (int i = 1; i < M; i += 2)
        all_bad.set(i);
}

void state::update()
{
    int M = implies.size();
    bool more = true;
    while (more)
    {
        for (int y = 0; y < M; y++)
            for (int x = 0; x < M; x++)
                if (implies[x][y])
                    implies[x] |= implies[y];
        for (int i = 0; i < M; i++)
            if (implies[i ^ 1][i])
                known[i] = true;
        more = false;
        for (int i = 0; i < M; i++)
        {
            if (known[i ^ 1])
                continue;
            bs cknown = known | implies[i];
            if (int((cknown & all_bad).count()) * 4 >= M)
            {
                more = true;
                implies[i][i ^ 1] = true;
            }
        }
        for (int i = 0; i < M; i++)
            for (int j = i + 1; j < M; j++)
            {
                if ((i >> 1) == (j >> 1))
                    continue;
                if (known[i ^ 1] || known[j ^ 1] || implies[i][j ^ 1])
                    continue;
                bs cknown = known | implies[i] | implies[j];
                if (int((cknown & all_bad).count()) * 4 >= M)
                {
                    more = true;
                    implies[i][j ^ 1] = true;
                    implies[j][i ^ 1] = true;
                }
            }
    }
}

void state::add(int x, int y)
{
    if (implies[x][y])
        return;
    implies[x][y] = true;
    implies[y ^ 1][x ^ 1] = true;
}

int state::status(int x) const
{
    if (known[2 * x])
        return 1;
    else if (known[2 * x + 1])
        return 0;
    else
        return -1;
}

bool state::tested(int x, int y) const
{
    return implies[2 * x][2 * y] || implies[2 * x][2 * y + 1];
}

int main()
{
    std::mt19937 engine;
    ios::sync_with_stdio(false);
    int T;
    cin >> T;
    for (int cas = 0; cas < T; cas++)
    {
        int N;
        cin >> N;
        state s(2 * N);
        int nq = 0;
        vector<int> perm(N), rperm(N);
        for (int i = 0; i < N; i++)
            perm[i] = i;
#ifdef PRE_SHUFFLE
        shuffle(perm.begin(), perm.end(), engine);
#endif
        for (int i = 0; i < N; i++)
            rperm[perm[i]] = i;
        while (s.known_count() < N)
        {
            vector<int> query(N, -1);
            vector<int> good, bad, ugly;
            for (int i = 0; i < N; i++)
            {
                switch (s.status(i))
                {
                case 1: good.push_back(i); break;
                case 0: bad.push_back(i); break;
                case -1: ugly.push_back(i); break;
                }
            }
            shuffle(good.begin(), good.end(), engine);
            shuffle(bad.begin(), bad.end(), engine);
            shuffle(ugly.begin(), ugly.end(), engine);
            int uu = 0;
            for (size_t i = 0; i < min(good.size(), ugly.size()); i++, uu++)
                query[good[i]] = ugly[i];
            vector<int> order;
            copy(good.begin(), good.end(), back_inserter(order));
            copy(bad.begin(), bad.end(), back_inserter(order));
            copy(ugly.begin() + uu, ugly.end(), back_inserter(order));
            for (auto x : ugly)
            {
                if (order.empty())
                    break;
                int p = order.size() - 1;
                while (p >= 0 && s.tested(x, order[p]))
                    p--;
                if (p < 0)
                    continue;
                swap(order[p], order.back());
                query[x] = order.back();
                order.pop_back();
            }
            cout << "test";
            for (int i = 0; i < N; i++)
            {
                int q = query[rperm[i]];
                cout << ' ' << (q == -1 ? 0 : perm[q] + 1);
            }
            cout << endl;
            string answer;
            cin >> answer;
            for (int i = 0; i < N; i++)
            {
                if (query[i] == -1)
                    continue;
                int v = answer[perm[i]] - '0';
                s.add(2 * i, 2 * query[i] + 1 - v);
            }
            s.update();
            nq++;
        }

        cout << "answer ";
        for (int i = 0; i < N; i++)
            cout << s.status(rperm[i]);
        cout << endl;
#ifdef REPORT_QUERIES
        ofstream of("querycount-bmerry-random.txt", ios::app);
        of << nq << '\n';
        of.close();
#endif
    }
    return 0;
}
