// Does full transitive closure in n^3 time for each query.
// Will probably be too slow, but OK if it passes.
#include <bits/stdc++.h>
using namespace std;

typedef vector<int> vi;
typedef vector<vi> matrix;

struct State {
    matrix known;
    int n;

    State(int n): n(n), known(matrix(2*n, vi(2*n, 0))) {
        for (int i = 0; i < 2*n; ++i)
            known[i][i] = true;
    }

    int done(string &sol) {
        int res = 0;
        for (int i = 0; i < n; ++i) {
            if (known[2*i][2*i+1] || known[2*i+1][2*i]) {
                sol[i] = known[2*i][2*i+1] ? '0' : '1';
                ++res;
                continue;
            }
            int a = 0, b = 0;
            for (int j = 0; j < n; ++j) {
                a += known[2*i][2*j+1];
                b += known[2*i+1][2*j+1];
            }
            if (2*a >= n || 2*b >= n) {
                sol[i] = 2*a >= n ? '0' : '1';
                ++res;
                continue;
            }
        }
        return res;
    }

    void process(const vi &perm, const string &response) {
        for (int i = 0; i < n; ++i) {
            if (perm[i] == -1) continue;
            int o = 2*perm[i] + (response[i] == '0');
            known[2*i][o] = true;
            known[o^1][2*i+1] = true;
        }
        for (int k = 0; k < 2*n; ++k)
            for (int i = 0; i < 2*n; ++i)
                for (int j = 0; j < 2*n; ++j)
                    known[i][j] |= known[i][k] && known[k][j];
    }

    vi next_query() {
        string sol(n, '.');
        done(sol);
        vi res(n, -1);
        vi good, unknown;
        for (int i = 0; i < n; ++i) {
            if (sol[i] == '1') good.push_back(i);
            if (sol[i] == '.') unknown.push_back(i);
        }
        random_shuffle(unknown.begin(), unknown.end());
        for (int x: good) {
            if (!unknown.empty()) {
                res[x] = unknown.back();
                unknown.pop_back();
            }
        }
        if (!unknown.empty()) {
            int prev = unknown.back();
            for (int x: unknown) {
                res[prev] = x;
                prev = x;
            }
        }
        return res;
    }
};


void run_once() {
    int n;
    scanf("%d", &n);
    State S(n);
    string sol(n, ' ');
    while (S.done(sol) != n) {
        auto query = S.next_query();
        printf("test");
        for (int v: query)
            printf(" %d", v+1);
        printf("\n");
        fflush(stdout);

        char answer[n+100];
        scanf("%s", answer);
        S.process(query, answer);
    }
    printf("answer %s\n", sol.c_str());
    fflush(stdout);
}

int main(void) {
    int testcnt;
    scanf("%d", &testcnt);
    while (testcnt-->0)
        run_once();
}
