#!/usr/bin/env python3
import sys, os, random

random.seed(hash('icpc2020'))

if os.listdir():
    print('Error: directory not empty')
    sys.exit(1)

class TestCase(object):
    def __init__(self, v, c, levels, expected=None):
        self.v = v
        self.c = c
        self.levels = levels
        self.ans = self.solve()

        if expected is not None:
            assert self.ans == expected

    def solve(self):
        n, v, c = len(self.levels), self.v, self.c
        levels = list(self.levels)
        tot = sum(x for x, _ in levels)
        levels.sort(key=lambda l: c * l[0] + v * l[1])
        gains = set([0])
        for x, d in levels:
            print(len(gains))
            new_gains = set()
            for gain in gains:
                new_gains.add(gain)
                if c * gain < v * d:
                    new_gains.add(gain + x)

            gains = new_gains

        ans = max(gains)
        return tot + (c - 1) * ans

    def in_lines(self):
        return ['{} {} {}'.format(len(self.levels), self.v, self.c)] +\
            ['{} {}'.format(x, d) for x, d in self.levels]

    def out_lines(self):
        return ['{}'.format(self.ans)]

test_num = 0
def write_test(base_path, tc, name=''):
    if not os.path.exists(base_path):
        os.makedirs(base_path)
    global test_num
    name = ('{:02d}'.format(test_num)) + ('_' + name if name else '')
    fn_in = os.path.join(base_path, name + '.in')
    with open(fn_in, 'w') as f_in:
        f_in.write(''.join(map(lambda x: x + '\n', tc.in_lines())))
    fn_ans = os.path.join(base_path, name + '.ans')
    with open(fn_ans, 'w') as f_ans:
        f_ans.write(''.join(map(lambda x: x + '\n', tc.out_lines())))
    test_num += 1

def sample_1():
    return TestCase(10, 2, [(15, 1), (2, 2), (9, 1)])

def massive():
    levels = []
    x = 1
    while x < 2000:
        levels.append((x, 1000000))
        x *= 2
    levels = levels * 30

    return TestCase(2000, 2000, levels)

def every():
    levels = [(x, 1000000) for x in range(1, 2001)]
    return TestCase(2000, 2000, levels)

def all_max():
    return TestCase(2000, 2000, [(2000, 1000000) for _ in range(2000)])

write_test('sample', sample_1())

write_test('secret', massive())
write_test('secret', every())
write_test('secret', all_max())
