import java.io.*;
import java.util.*;

public class ArknaveBitset {
    static int v;
    static int c;

    static boolean DEBUG = false;

    public static void main(String[] args) throws IOException {
        final BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
        StringTokenizer st = new StringTokenizer(br.readLine());

        final int n = Integer.parseInt(st.nextToken());
        v = Integer.parseInt(st.nextToken());
        c = Integer.parseInt(st.nextToken());

        int totalXP = 0;

        final Level[] levels = new Level[n];
        for (int i = 0; i < n; i++) {
            st = new StringTokenizer(br.readLine());
            int xp = Integer.parseInt(st.nextToken());
            int target = Integer.parseInt(st.nextToken());
            levels[i] = new Level(xp, target);

            totalXP += xp;
        }

        if (DEBUG)
            System.err.printf("TotalXP: %d%n", totalXP);

        Arrays.sort(levels);

        final Bitset dp = new Bitset(totalXP + 1);
        for (Level level : levels) {
            int start = Math.min((v * level.target + c - 1) / c - 1, totalXP - level.xp);
            dp.shift(start, level.xp);
            if (DEBUG) {
                System.err.println(dp);
            }
        }

        int ans = dp.getLast();
        ans = totalXP + (c - 1) * ans;

        if (DEBUG) {
            System.out.printf("Last: %d%n", dp.getLast());
        }

        System.out.println(ans);
    }

    public static class Level implements Comparable<Level> {
        private int xp;
        private int target;

        public Level(int xp, int target) {
            this.xp = xp;
            this.target = target;
        }

        public int getScore() {
            return c * xp + v * target;
        }

        public int compareTo(Level other) {
            return Integer.compare(this.getScore(), other.getScore());
        }
    }

    public static class Bitset {
        public static long[] bits;

        Bitset(int length) {
            int chunks = (length + 63) >> 6;
            bits = new long[chunks];

            bits[0] = 1;
        }

        public int getLast() {
            int bitIndex = bits.length * 64 - 1;
            int chunkIndex = bits.length - 1;
            while (bits[chunkIndex] == 0) {
                chunkIndex--;
                bitIndex -= 64;
            }

            int base = bitIndex & 0x3f;
            while ((bits[chunkIndex] & (1L << base)) == 0) {
                --bitIndex;
                --base;
            }

            return bitIndex;
        }

        /**
         * Equivalent to taking the bits before cap, shifting them by amt, and ORing
         */
        public void shift(int cap, int amt) {
            if (DEBUG)
                System.err.printf("Shift cap %d amt %d%n", cap, amt);

            for (int chunkIndex = (cap >> 6); chunkIndex >= 0; chunkIndex--) {
                long val = bits[chunkIndex];
                int lowBit = chunkIndex << 6;
                if (val == 0 || lowBit > cap) {
                    continue;
                }

                if (DEBUG)
                    System.err.printf("OrigVal  %016x%n", val);

                if (lowBit <= cap && cap < lowBit + 64) {
                    int bitsToTake = (cap + 1) & 0x3f;
                    if (bitsToTake > 0) {
                        if (DEBUG)
                            System.err.printf("Mask     %016x%n", (1L << bitsToTake) - 1);
                        val &= (1L << bitsToTake) - 1;
                    }
                }

                apply(val, lowBit + amt);
            }
        }

        // OR the bits in val starting at start
        private void apply(long val, int start) {
            if (DEBUG)
                System.err.printf("Applying %016x start %d%n", val, start);

            int chunkIndex = start >> 6;
            int boost = start & 0x3f;
            bits[chunkIndex] |= val << boost;

            if (DEBUG)
                System.err.printf("Chunk %d Boost %d first %016x second %016x%n", chunkIndex, boost, val << boost, val >>> (64 - boost));

            val >>>= (64 - boost);
            if (boost != 0 && val != 0) {
                bits[chunkIndex + 1] |= val;
            }
        }

        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            for (int i = 0; i < bits.length; ++i) {
                for (long j = 0; j < 64; ++j) {
                    if ((bits[i] & (1L << j)) != 0) {
                        sb.append(64 * i + j);
                        sb.append(' ');
                    }
                }
            }

            return sb.toString();
        }
    }
}
