// Sorts on incorrect key

#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using word = unsigned long long;
static constexpr int WORD_BITS = CHAR_BIT * sizeof(word);

struct quest
{
    ll xp;
    ll d;

    bool operator<(const quest &other) const
    {
        return d < other.d;
    }
};

class mybitset
{
private:
    size_t size;
    vector<word> bits;

public:
    explicit mybitset(size_t size = 0) : size(size), bits(size / WORD_BITS + 1) {}

    bool operator[](size_t idx) const
    {
        assert(idx < size);
        return (bits[idx / WORD_BITS] >> (idx % WORD_BITS)) & 1;
    }

    void set(size_t idx)
    {
        assert(idx < size);
        bits[idx / WORD_BITS] |= word(1) << (idx % WORD_BITS);
    }

    // Shift bottom `clip` bits left by `dist`
    mybitset shl_clip(size_t dist, size_t clip) const
    {
        mybitset out(size);
        if (dist >= size)
            return out;
        clip = min(clip, size - dist);
        int end_shift = dist % WORD_BITS;
        int eclip = clip + dist;
        if (end_shift)
        {
            int start_shift = WORD_BITS - end_shift;
            int limit = (eclip + WORD_BITS - 1) / WORD_BITS;
            int offset = dist / WORD_BITS + 1;
            out.bits[offset - 1] = bits[0] << end_shift;
            for (int i = offset; i < limit; i++)
                out.bits[i] = (bits[i - offset] >> start_shift) | (bits[i - offset + 1] << end_shift);
        }
        else
        {
            int len = (clip + WORD_BITS - 1) / WORD_BITS;
            copy(bits.begin(), bits.begin() + len, out.bits.begin() + dist / WORD_BITS);
        }
        if (eclip % WORD_BITS)
            out.bits[eclip / WORD_BITS] &= (word(1) << (eclip % WORD_BITS)) - 1;
        return out;
    }

    mybitset &operator|=(const mybitset &other)
    {
        assert(size == other.size);
        for (size_t i = 0; i < bits.size(); i++)
            bits[i] |= other.bits[i];
        return *this;
    }

    int top_bit() const
    {
        for (int i = int(bits.size()) - 1; i >= 0; i--)
        {
            if (bits[i] != 0)
            {
                for (int j = WORD_BITS - 1; j >= 0; j--)
                    if ((bits[i] >> j) & 1)
                        return i * WORD_BITS + j;
            }
        }
        return -1;
    }
};

#ifdef RUN_TEST
void test_shl()
{
    mt19937 engine;
    uniform_int_distribution<int> size_dist(1, 200);
    uniform_int_distribution<int> dist_dist(0, 200);
    uniform_int_distribution<int> clip_dist(0, 200);
    bernoulli_distribution coin(0.6);
    for (int pass = 0; pass < 200000; pass++)
    {
        int size = size_dist(engine);
        mybitset b(size);
        for (int i = 0; i < size; i++)
            if (coin(engine))
                b.set(i);
        int dist = dist_dist(engine);
        int clip = clip_dist(engine);
        mybitset actual = b.shl_clip(dist, clip);
        mybitset expected(size);
        for (int i = 0; i < min(size, clip); i++)
            if (i + dist < size && b[i])
                expected.set(i + dist);
        for (int i = 0; i < size; i++)
            assert(expected[i] == actual[i]);
    }
}
#endif

int main()
{
#ifdef RUN_TEST
    test_shl();
#endif

    int N;
    ll V, C, sum_xp = 0;
    cin >> N >> V >> C;
    vector<quest> quests(N);
    for (int i = 0; i < N; i++)
    {
        ll d;
        cin >> quests[i].xp >> d;
        // min x such that x * C / V >= d
        // x * C >= d * V
        quests[i].d = (d * V + C - 1) / C;
        sum_xp += quests[i].xp;
    }
    sort(quests.begin(), quests.end());

    mybitset knap(sum_xp + 1);
    knap.set(0);
    for (const quest &q : quests)
    {
        knap |= knap.shl_clip(q.xp, q.d);
    }
    ll best = knap.top_bit();
    ll score = best * (C - 1) + sum_xp;
    cout << score << '\n';
}
