// Find two longest edge-disjoint paths, subtract from cost of a covering loop

import java.util.*;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.StringTokenizer;

class Vertex {
  public int id;
  public ArrayList<Integer> nbr;
  public ArrayList<Integer> dist;
  public int max1[], // <= costs of each of four longest paths ending here
             max2[],
             max3[],   // longest pair of paths extensible through parent
             max4[];   // longest pair of paths NOT extensible through parent
  public int x1[], x2[], x3[], x4[]; // child associated with each type of path

//  public ArrayList<Integer> x1,  x4; // children associated with max1 and max4

  public Vertex(int i) {
    id = i;
    nbr = new ArrayList<Integer>();
    dist = new ArrayList<Integer>();
    max1 = new int[5];
    max2 = new int[4];
    max3 = new int[4];
    max4 = new int[4];
    x1 = new int[5];
    x2 = new int[4];
    x3 = new int[4];
    x4 = new int[4];
  }
}

public class RSRFasterSnow {
  public static BufferedReader in;
  public static StringTokenizer st;
  public static int n; // number of vertices
  public static Vertex[] gr; // vertices of the graph
  public static int sum; // 2*sum of all edge weights
//  public static boolean visited[];

  public static void main(String[] args) throws IOException {
    in = new BufferedReader(new InputStreamReader(System.in));
    n = Integer.parseInt(in.readLine());

    gr = new Vertex[n];
    sum = 0;
    for (int i = 0; i < n-1; i++) {
      st = new StringTokenizer(in.readLine());
      int v = Integer.parseInt(st.nextToken())-1; // zero-adjust indices
      int w = Integer.parseInt(st.nextToken())-1;
      int d = Integer.parseInt(st.nextToken());
      if (gr[v]==null) {
        gr[v] = new Vertex(v);
      }
      if (gr[w]==null) {
        gr[w] = new Vertex(w);
      }
      gr[v].nbr.add(w);
      gr[w].nbr.add(v);
      gr[v].dist.add(d);
      gr[w].dist.add(d);
      sum += d;
    }
    sum *=2;

    // starting at a leaf simplifies handling at root of the dfs
    int i = 0;
    while (i < n && gr[i].nbr.size() > 1) i++;   
    dfs(i,-1);
    int max = Math.max(gr[i].max1[0],Math.max(gr[i].max3[0],gr[i].max4[0]));
    System.out.println(sum-max);
  }

  public static void dfs(int v, int p) {
    for (int i = 0; i < gr[v].nbr.size(); i++) {
      int w = gr[v].nbr.get(i);
      if (w == p) continue;
      int d = gr[v].dist.get(i);
      dfs(w,v);

// Extend single path
      insert(d+gr[w].max1[0], gr[v].max1, w, gr[v].x1);

// Pass up double path
      insert(gr[w].max2[0], gr[v].max2, w, gr[v].x2);

// Extend one arm of double path using parent
      insert(d+gr[w].max3[0], gr[v].max3, w, gr[v].x3);

// Pass up a two-path solution without extending it:
      insert(gr[w].max4[0], gr[v].max4, w, gr[v].x4);

    }

// Update the max4 info (since it won't affect the updates of the
// max3 info):

    // Complete a second path (not using parent edge)...
    if (gr[v].nbr.size() >= 2) {
      for (int i = 0; i < 2; i++) {
        for (int j = 0; j < 2; j++) {
          if (gr[v].x1[i] == gr[v].x3[j]) continue;
          insert(gr[v].max1[i] + gr[v].max3[j],gr[v].max4,-1,gr[v].x4);
         }
       }
     }

     // ... and add up best 4 paths 
    insert(gr[v].max1[0]+gr[v].max1[1]+gr[v].max1[2]+gr[v].max1[3],gr[v].max4, -1, gr[v].x4);

     // ... and add up best pair of double paths:
    insert(gr[v].max2[0]+gr[v].max2[1],gr[v].max4, -1, gr[v].x4);

     // ... and add best max1 paths + best max2 path:

     if (gr[v].nbr.size() >= 3) {
       for (int i = 0; i < 4; i++) {
         for (int j = i+1; j < 4; j++) {
           for (int k = 0; k < 3; k++) {
             if (gr[v].x2[k] < 0 || gr[v].x1[i]==gr[v].x2[k] || gr[v].x1[j]==gr[v].x2[k]) continue;
             insert(gr[v].max1[i]+gr[v].max1[j]+gr[v].max2[k],gr[v].max4,-1,gr[v].x4);
           }
         }
       }
     }

// Update the max3 information. 

    int triple = gr[v].max1[0]+gr[v].max1[1]+gr[v].max1[2];
    insert(triple, gr[v].max3, -1,gr[v].x3); 

    if (gr[v].nbr.size() >= 2) {
      for (int i = 0; i < 2; i++) {
        for (int j = 0; j < 2; j++) {
          if (gr[v].x1[i] == gr[v].x2[j]) continue;
          insert(gr[v].max1[i]+gr[v].max2[j],gr[v].max3,-1,gr[v].x3);
        }
      }
    }

// Update the max2 information.

    if (gr[v].nbr.size() >=2) 
      insert(gr[v].max1[0]+gr[v].max1[1],gr[v].max2,-1,gr[v].x2);

  }

  public static void insert(int w, int[] a, int nb, int[] x)  {
    int n = a.length;
    if (w <= a[n-2]) {
      return;
    }
    int i = n-2;
      while (i >= 0 && w > a[i]) {
        a[i+1] = a[i];
        x[i+1] = x[i];
        i--;
      }
     a[i+1] = w;
     x[i+1] = nb;
  }
}
