    #include <iostream>
#include <iomanip>
#include <queue>
#include <cstdlib>
#include <ctime>
using namespace std;

const int MAX = 100000;      // max number of nodes

class edge
{
public:
    int w;
    int dist;
    edge* next;
    edge* other;        // pointer to corresponding edge in other direction
    bool canBeRemoved;

    edge(int other, int d, edge* n=0) : w(other), dist(d), next(n), canBeRemoved(true)
    {}
};

class node
{
public:
    edge *adj;
    bool visited;   // used for mcst
    int dist;       // used for mcst
    int prev;       // used for mcst
    int nedges;
    int longestDist[5];     // longest distances of paths leaving this node
    int longestDir[5];      // corresponding first node on these paths
    int longestAway[5];     // longest distances of paths not going through node
    int longestAwayDir[5];  // corresponding first node in direction of these paths
    int numLong;
};

class graph
{
public:
    int nnodes;
    node nodes[MAX];

    graph(int n) : nnodes(n)
    {
        for(int i=0; i<nnodes; i++) {
            nodes[i].adj = 0;
            nodes[i].nedges = 0;
        }
    }

    ~graph()
    {
        for(int i=0; i<nnodes; i++) {
            for(edge *p = nodes[i].adj; p != 0; ) {
                edge* next = p->next;
                delete p;
                p = next;
            }
        }
    }

    void addEdge(int n1, int n2, int dist)
    {
        nodes[n1].adj = new edge(n2, dist, nodes[n1].adj);
        nodes[n1].nedges++;
        nodes[n2].adj = new edge(n1, dist, nodes[n2].adj);
        nodes[n2].nedges++;
        nodes[n1].adj->other = nodes[n2].adj;
        nodes[n2].adj->other = nodes[n1].adj;
    }

    bool isEdge(int n1, int n2)
    {
        for(edge* p = nodes[n1].adj; p != 0; p = p->next)
            if (p->w == n2)
                return true;
        return false;
    }

    bool foundDist(int w, int dist, int v)
    {
        for(int j=0; j<nodes[w].numLong; j++) {
            if (nodes[w].longestDist[j] == dist && nodes[w].longestDir[j] == v)
                return true;
        }
        return false;
    }

    bool foundAway(int w, int dist, int v)
    {
        for(int j=0; j<nodes[w].numLong; j++) {
            if (nodes[w].longestAway[j] == dist && nodes[w].longestAwayDir[j] == v)
                return true;
        }
        return false;
    }

    void addDist(int w, int v, int dist, int awayDist)
    {
        if (!foundDist(w, dist, v)) {
            if (nodes[w].numLong < 4 || dist >= nodes[w].longestDist[3]) {
                int j=nodes[w].numLong;
                if (j > 3)
                    j = 3;                      //only need to store top 4
                while (j > 0 && nodes[w].longestDist[j-1] < dist) {
                    nodes[w].longestDist[j] = nodes[w].longestDist[j-1];
                    nodes[w].longestDir[j] = nodes[w].longestDir[j-1];
                    j--;
                }
                nodes[w].longestDist[j] = dist;
                nodes[w].longestDir[j] = v;
            }
        }
        if (!foundAway(w, awayDist, v)) {
            if (nodes[w].numLong < 4 || awayDist >= nodes[w].longestAway[3]) {
                int j=nodes[w].numLong;
                if (j > 3)
                    j = 3;                      //only need to store top 4
                while (j > 0 && nodes[w].longestAway[j-1] < awayDist) {
                    nodes[w].longestAway[j] = nodes[w].longestAway[j-1];
                    nodes[w].longestAwayDir[j] = nodes[w].longestAwayDir[j-1];
                    j--;
                }
                nodes[w].longestAway[j] = awayDist;
                nodes[w].longestAwayDir[j] = v;
    //            if (nodes[w].numLong < 4)
                    nodes[w].numLong++;
            }
        }
    }

    void print()
    {
        for(int i=0; i<nnodes; i++) {
            cout << setw(4) << i << ":";
            for(edge* p=nodes[i].adj; p!=0; p=p->next)
                cout << ' ' << p->w << '(' << p->dist << ')';
            cout << endl;
        }
    }
};

graph *tree;

void calcDists(graph* tree)
{
    int n = tree->nnodes;
    queue<int> q;
    for(int i=0; i<n; i++) {
        tree->nodes[i].numLong = 0;
        for(int j=0; j<4; j++) {
            tree->nodes[i].longestDist[j] = 0;
            tree->nodes[i].longestAway[j] = 0;
        }
        tree->nodes[i].visited = false;
        if (tree->nodes[i].nedges == 1)     // push leaves on queue
            q.push(i);
    }
                                // first pass: move from leaves to interior nodes
    int v;
    if (q.empty())
        return;
    while (true) {
        v = q.front();
        q.pop();
        tree->nodes[v].visited = true;
        edge* p = tree->nodes[v].adj;
        while (p != 0 && tree->nodes[p->w].visited)
            p = p->next;
        if (p ==0)
            break;
        int w = p->w;
        int maxAway = tree->nodes[v].longestDist[0] + tree->nodes[v].longestDist[1];
        if (tree->nodes[v].longestAway[0] > maxAway)
            maxAway = tree->nodes[v].longestAway[0];
        tree->addDist(w, v, tree->nodes[v].longestDist[0] + p->dist, maxAway);
        if (tree->nodes[w].numLong == tree->nodes[w].nedges-1)
            q.push(w);
    }
                                    // second pass: head back to leaves
    for(int i=0; i<n; i++) {
        tree->nodes[i].visited = false;
    }
    q.push(v);
    while (!q.empty()) {
        int v = q.front();
        q.pop();
        tree->nodes[v].visited = true;
        for (edge* p = tree->nodes[v].adj; p!= 0; p=p->next) {
            int w = p->w;
            if (tree->nodes[w].visited)
                continue;
            int dist = tree->nodes[v].longestDist[0] + p->dist;
            if (w == tree->nodes[v].longestDir[0])
                dist = tree->nodes[v].longestDist[1] + p->dist;
            int maxAway = 0;
            if (w == tree->nodes[v].longestDir[0])
                maxAway = tree->nodes[v].longestDist[1] + tree->nodes[v].longestDist[2];
            else if (w == tree->nodes[v].longestDir[1])
                maxAway = tree->nodes[v].longestDist[0] + tree->nodes[v].longestDist[2];
            else
                maxAway = tree->nodes[v].longestDist[0] + tree->nodes[v].longestDist[1];
            if (w == tree->nodes[v].longestAwayDir[0] && tree->nodes[v].longestAway[1] > maxAway)
                maxAway = tree->nodes[v].longestAway[1];
            if (w != tree->nodes[v].longestAwayDir[0] && tree->nodes[v].longestAway[0] > maxAway)
                maxAway = tree->nodes[v].longestAway[0];
            tree->addDist(w, v, dist, maxAway);
            q.push(w);
        }
    }
}

int readTree(int m)
{
    tree = new graph(m);
    int total = 0;
    for(int i=0; i<m-1; i++) {
        int n1, n2, dist;
        cin >> n1 >> n2 >> dist;
        tree->addEdge(n1-1, n2-1, dist);
        total += dist;
    }
    return total;
}

void addToTree(graph* t, int v, int prev)
{
    for(edge *p=tree->nodes[v].adj; p != 0; p=p->next) {
        if (p->w != prev) {
            t->addEdge(v, p->w, p->dist);
            addToTree(t, p->w, v);
        }
    }
}

void buildTrees(int v1, int v2, graph *t1, graph *t2)
{
    addToTree(t1, v1, v2);
    addToTree(t2, v2, v1);
}

int main()
{
    int nnodes;
    cin >> nnodes;
    int lenCleared = readTree(nnodes);
    calcDists(tree);
//for(int j = 0; j<tree->nnodes; j++) {
//    node n = tree->nodes[j];
//    cout << j << endl;
//    for(int i=0; i<5; i++) {
//        cout << n.longestDist[i] << '\t' << n.longestDir[i] << '\t'  << n.longestAway[i] << '\t' << n.longestAwayDir[i]<< endl;
//   }
//}
    int lenNotRepeated = 0;
    for(int i=0; i<nnodes; i++) {
        node* pn = tree->nodes + i;
        int sum = pn->longestDist[0];    // check for crossed paths
        for(int j=1; j<4; j++)

            sum += pn->longestDist[j];
        if (sum > lenNotRepeated)
            lenNotRepeated = sum;
                                                    // check for uncrossed paths not using this node
        if (pn->longestAway[0] + pn->longestAway[1] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[0] + pn->longestAway[1];
                                                    // check for uncrossed paths using this node
        if (pn->longestAwayDir[0] == pn->longestDir[0] &&
            pn->longestAway[0] + pn->longestDist[1] + pn->longestDist[2] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[0] + pn->longestDist[1] + pn->longestDist[2];
        else if (pn->nedges > 1 && pn->longestAwayDir[0] == pn->longestDir[1] &&
            pn->longestAway[0] + pn->longestDist[0] + pn->longestDist[2] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[0] + pn->longestDist[0] + pn->longestDist[2];
        else if (pn->nedges > 2 && pn->longestAwayDir[0] != pn->longestDir[0] && pn->longestAwayDir[0] != pn->longestDir[1] &&
            pn->longestAway[0] + pn->longestDist[0] + pn->longestDist[1] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[0] + pn->longestDist[0] + pn->longestDist[1];
        if (pn->longestAwayDir[1] == pn->longestDir[0] &&
            pn->longestAway[1] + pn->longestDist[1] + pn->longestDist[2] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[1] + pn->longestDist[1] + pn->longestDist[2];
        else if (pn->nedges > 1 && pn->longestAwayDir[1] == pn->longestDir[1] &&
            pn->longestAway[1] + pn->longestDist[0] + pn->longestDist[2] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[1] + pn->longestDist[0] + pn->longestDist[2];
        else if (pn->nedges > 2 && pn->longestAwayDir[1] != pn->longestDir[0] && pn->longestAwayDir[1] != pn->longestDir[1] &&
            pn->longestAway[1] + pn->longestDist[0] + pn->longestDist[1] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[1] + pn->longestDist[0] + pn->longestDist[1];
        if (pn->longestAwayDir[2] == pn->longestDir[0] &&
            pn->longestAway[2] + pn->longestDist[1] + pn->longestDist[2] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[2] + pn->longestDist[1] + pn->longestDist[2];
        else if (pn->nedges > 1 && pn->longestAwayDir[2] == pn->longestDir[1] &&
            pn->longestAway[2] + pn->longestDist[0] + pn->longestDist[2] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[2] + pn->longestDist[0] + pn->longestDist[2];
        else if (pn->nedges > 2 && pn->longestAwayDir[2] != pn->longestDir[0] && pn->longestAwayDir[2] != pn->longestDir[1] &&
            pn->longestAway[2] + pn->longestDist[0] + pn->longestDist[1] > lenNotRepeated)
            lenNotRepeated = pn->longestAway[2] + pn->longestDist[0] + pn->longestDist[1];
    }
    cout << 2*lenCleared-lenNotRepeated << endl;
}
