#include <algorithm>
#include <functional>
#include <iostream>
#include <vector>
using namespace std;

const int FAIL_PART = 4;
const int FAIL_PART_I = 7;
const int N = 1000;
const int TREE = 50;

static vector<vector<vector<int>>> partitions{
  {},
  {{1}},
  {{2}, {1,1}},
  {{3}, {2,1}, {1,2}, {1,1,1}},
  {{4}, {3,1}, {2,2}, {2,1,1}, {1,3}, {1,2,1}, {1,1,2}, {1,1,1,1}}
};

vector<vector<pair<int, int>>> g;

vector<int> doit(int x, int prev) {
  vector<vector<pair<int, int>>> best(5);
  for (auto [y, d] : g[x]) if (y != prev) {
    auto v = doit(y, x);
    for (int i = 1; i <= 4; i++) best[i].push_back({v[i] + (i%2 ? d : 0), y});
  }
  for (int i = 1; i <= 4; i++) {
    sort(best[i].begin(), best[i].end(), greater<pair<int, int>>());
  }

  vector<int> ret(5);
  for (int i = 1; i <= 4; i++) {
    for (auto const& partition : partitions[i]) {
      vector<int> seen, idx(5);
      int cur = 0;
      for (auto x : partition) {
        for (; idx[x] < best[x].size(); idx[x]++) {
          auto [value, nd] = best[x][idx[x]];
          if (find(seen.begin(), seen.end(), nd) == seen.end()) {
            seen.push_back(nd);
            cur += value;
            break;
          }
        }
      }
      ret[i] = max(ret[i], cur);
    }
  }
  return ret;
}

int main() {
  srand(time(0));
  for (int cases = 0;; cases++) {
    vector<vector<int>> e;
    if (FAIL_PART == 4 && FAIL_PART_I == 5) {
      e = {{1, 2,  500},
           {1, 3,  400},
           {1, 4,  300},
           {2, 5,  500},
           {2, 6,  500},
           {3, 7,  410},
           {3, 8,  410},
           {4, 9,  300},
           {4, 10, 300}};
      for (int i = e.size()+1; i < N; i++) e.push_back({i+1, 1, rand()%5+1});
    } else if (FAIL_PART == 4 && FAIL_PART_I == 6) {
      e = {{1, 2,  500},
           {1, 3,  400},
           {1, 4,  300},
           {2, 5,  500},
           {2, 6,  500},
           {3, 7,  400},
           {3, 8,  400},
           {4, 9,  310},
           {4, 10, 310}};
      for (int i = e.size()+1; i < N; i++) e.push_back({i+1, 1, rand()%5+1});
    } else {
      for (int i = 1; i < TREE; i++) e.push_back({i+1, rand()%i+1, rand()%500+1});
      for (int i = e.size()+1; i < N; i++) e.push_back({i+1, i, 1});
    }

    g.clear();
    g.resize(N+1);
    for (int i = 0; i < N-1; i++) {
      int A = e[i][0], B = e[i][1], D = e[i][2];
      g[A].push_back({B, D});
      g[B].push_back({A, D});
    }

    int ret1 = doit(N, 0)[4];
    vector<int> p = partitions[FAIL_PART][FAIL_PART_I];
    partitions[FAIL_PART][FAIL_PART_I] = partitions[FAIL_PART][0];
    int ret2 = doit(N, 0)[4];
    partitions[FAIL_PART][FAIL_PART_I] = p;

    if (ret1 != ret2) {
      random_shuffle(e.begin(), e.end());
      for (int i = 0; i < e.size(); i++) if (rand()%2) swap(e[i][0], e[i][1]);
      vector<int> perm(N+1);
      for (int i = 1; i <= N; i++) perm[i] = i;
      random_shuffle(perm.begin()+1, perm.end());
      cout << N << endl;
      for (auto v : e) cout << perm[v[0]] << ' ' << perm[v[1]] << ' ' << v[2] << endl;
      cerr << "done!" << endl;
      return 0;
    } else {
      cerr << "matched " << cases << endl;
    }
  }
}
