import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.Queue;
import java.util.regex.Pattern;

/**
 * ACM ICPC World Finals 2020
 * Input Format Checker: Speed Limit
 * 
 * @author Martin Kacer
 */
public class SpeedLimitChecker {
	static int MIN_SIZE = 1, MAX_SIZE = 20_000, MAX_SPEED = 100_000, MAX_COST = MAX_SPEED;
	static Pattern PAT_FIRST = Pattern.compile("[1-9][0-9]* [1-9][0-9]*");
	static Pattern PAT_ROAD = Pattern.compile("[1-9][0-9]* [1-9][0-9]* [1-9][0-9]*");
	
	BufferedReader read = new BufferedReader(new InputStreamReader(System.in));

	public static void main(String[] args) throws Exception {
		SpeedLimitChecker inst = new SpeedLimitChecker();
		inst.checkInput();
	}
	
	HashSet<String> roads = new HashSet<>();
	ArrayList<ArrayList<Integer>> graph;
	BitSet visited;
	Queue<Integer> queue = new LinkedList<>();
	
	void checkInput() throws Exception {
		String sn = read.readLine();
		if (!PAT_FIRST.matcher(sn).matches())
			throw new IllegalArgumentException("invalid first line: " + sn);
		String[] ss = sn.split(" ");
		int n = Integer.parseInt(ss[0]), c = Integer.parseInt(ss[1]);
		if (n < MIN_SIZE || n > MAX_SIZE)
			throw new IllegalArgumentException("invalid number of nodes: " + sn);
		if (c < 1 || n > MAX_COST)
			throw new IllegalArgumentException("invalid speed limit: " + sn);
		
		graph = new ArrayList<>(n);
		for (int i = 0; i < n; ++i) graph.add(new ArrayList<>());
		
		for (int i = 1; i < n; ++i) {
			String sr = read.readLine();
			if (!PAT_ROAD.matcher(sr).matches())
				throw new IllegalArgumentException("invalid road line: " + sr);
			ss = sr.split(" ");
			int u = Integer.parseInt(ss[0]), v = Integer.parseInt(ss[1]), s = Integer.parseInt(ss[2]);
			if (u < 1 || u > n || v < 1 || v > n)
				throw new IllegalArgumentException("illegal node number (n="+n+"): " + sr);
			if (u == v)
				throw new IllegalArgumentException("loop found: " + sr);
			if (s < 1 || s > MAX_SPEED)
				throw new IllegalArgumentException("invalid speed limit: " + sr);
			if (!roads.add(u+"-"+v) || !roads.add(v+"-"+u))
				throw new IllegalArgumentException("duplicate road: " + sr);
			graph.get(u-1).add(v-1);
			graph.get(v-1).add(u-1);
		}
		if ((sn = read.readLine()) != null)
			throw new IllegalArgumentException("excess input: " + sn);
		
		visited = new BitSet(n);
		queue.add(0); visited.set(0);
		while (!queue.isEmpty()) {
			int idx = queue.poll();
			for (int g : graph.get(idx)) if (!visited.get(g)) {
				queue.add(g);
				visited.set(g);
			}
		}
		if (visited.cardinality() != n)
			throw new IllegalArgumentException("not all nodes visited, n="+n+": " + (visited.size() < 100 ? visited : "too-big"));
		
		System.exit(42);
	}
}
