// Solution taking quadratic time and O(n log n) memory

#include <bits/stdc++.h>

using namespace std;

typedef long long ll;

struct edge
{
    int trg;
    ll limit;

    edge() = default;
    edge(int trg, ll limit) : trg(trg), limit(limit) {}
};

struct node
{
    vector<edge> edges;   // adjacent edges, including to parent
    ll k = 0;             // best solution for subtree if root not upgraded
    vector<ll> f;         // best solution for subtree if root is updated to W[j]
    int size = 1;         // subtree size
};

static constexpr ll BIG = LLONG_MAX / 4;

/* Recursively determines the size of each subtree, and swaps the largest
 * child to the first position.
 */
static int make_size(vector<node> &nodes, int cur, int parent)
{
    node &n = nodes[cur];
    n.size = 1;
    int big_pos = -1;
    int big_size = -1;
    for (size_t i = 0; i < n.edges.size(); i++)
    {
        const edge &e = n.edges[i];
        if (e.trg == parent)
            continue;
        int sub = make_size(nodes, e.trg, cur);
        n.size += sub;
        if (sub > big_size)
        {
            big_size = sub;
            big_pos = i;
        }
    }
    if (big_pos > 0)
        swap(n.edges[0], n.edges[big_pos]);
    return n.size;
}

static void recurse(const vector<ll> &W, ll C, vector<node> &nodes, int cur, int parent)
{
    node &n = nodes[cur];
    for (const auto &e : n.edges)
    {
        if (e.trg == parent)
            continue;
        // Solve recursively for child
        recurse(W, C, nodes, e.trg, cur);
        node &c = nodes[e.trg];
        n.f.resize(W.size());
        ll s = e.limit;
        ll add = BIG;
        for (size_t i = 0; i < W.size(); i++)
        {
            ll x = W[i];
            if (x < s)
                n.f[i] = BIG;     // x is smaller than highest speed limit, so f_i(x) = inf
            else
            {
                n.f[i] += x - s + min(c.k + C, c.f[i]);
                add = min(add, x - s + c.f[i]);
            }
        }
        n.k += C + min(c.k + C, add);
        // Free memory from c to keep total usage to O(n log n)
        c.f.clear();
        c.f.shrink_to_fit();
    }
    n.f.resize(W.size());
}

int main()
{
    int N, C;
    cin >> N >> C;
    if (N == 1)
    {
        cout << "0\n";
        return 0;
    }
    vector<node> nodes(N);
    vector<ll> W(N - 1);

    // Load the data (and offset vertex indices to count from 0)
    for (int i = 0; i < N - 1; i++)
    {
        int u, v;
        ll s;
        cin >> u >> v >> s;
        u--;
        v--;
        nodes[u].edges.emplace_back(v, s);
        nodes[v].edges.emplace_back(u, s);
        W[i] = s;
    }
    // Make sorted list of unique initial speed limits
    sort(W.begin(), W.end());
    W.resize(unique(W.begin(), W.end()) - W.begin());

    make_size(nodes, 0, -1);
    recurse(W, C, nodes, 0, -1);
    // Find the best overall solution: root is either upgraded or not
    ll ans = *min_element(nodes[0].f.begin(), nodes[0].f.end());
    ans = min(ans, nodes[0].k);
    cout << ans << '\n';
}
