// Solution taking quadratic time and memory (which is too much memory)

#include <bits/stdc++.h>

using namespace std;

typedef long long ll;

struct edge
{
    int trg;
    ll limit;

    edge() = default;
    edge(int trg, ll limit) : trg(trg), limit(limit) {}
};

struct node
{
    vector<edge> edges;   // adjacent edges, including to parent
    ll k = 0;             // best solution for subtree if root not upgraded
    vector<ll> f;         // best solution for subtree if root is updated to W[j]
};

static constexpr ll BIG = LLONG_MAX / 4;

static void recurse(const vector<ll> &W, ll C, vector<node> &nodes, int cur, int parent)
{
    node &n = nodes[cur];
    n.f.resize(W.size());
    // For each child
    for (const auto &e : n.edges)
    {
        if (e.trg == parent)
            continue;
        // Solve recursively for child
        recurse(W, C, nodes, e.trg, cur);
        const node &c = nodes[e.trg];

        ll s = e.limit;
        ll add = BIG;
        for (size_t i = 0; i < W.size(); i++)
        {
            ll x = W[i];
            if (x < s)
                n.f[i] = BIG;     // x is smaller than highest speed limit, so f_i(x) = inf
            else
            {
                n.f[i] += x - s + min(c.k + C, c.f[i]);
                add = min(add, x - s + c.f[i]);
            }
        }
        n.k += C + min(c.k + C, add);
    }
}

int main()
{
    int N, C;
    cin >> N >> C;
    vector<node> nodes(N);
    vector<ll> W(N - 1);

    // Load the data (and offset vertex indices to count from 0)
    for (int i = 0; i < N - 1; i++)
    {
        int u, v;
        ll s;
        cin >> u >> v >> s;
        u--;
        v--;
        nodes[u].edges.emplace_back(v, s);
        nodes[v].edges.emplace_back(u, s);
        W[i] = s;
    }
    // Make sorted list of unique initial speed limits
    sort(W.begin(), W.end());
    W.resize(unique(W.begin(), W.end()) - W.begin());

    recurse(W, C, nodes, 0, -1);
    // Find the best overall solution: root is either upgraded or not
    ll ans = *min_element(nodes[0].f.begin(), nodes[0].f.end());
    ans = min(ans, nodes[0].k);
    cout << ans << '\n';
}
