#!/usr/bin/env python3
import sys

INF = 2000000000

class Node:
	def __init__(self, idx):
		self.edges = []
		self.idx = idx


class Edge:
	def __init__(self, node, prev, speed):
		self.node = node
		self.prev = prev
		self.speed = speed


class SubResult:

	def __init__(self, deg, inc, sum):
		self.si, self.mi, self.ci = [], [], []
		self.deg, self.inc = deg, inc
		self.unbal = sum + deg * costsign
		self.idx = 0
	
	def cost_for(self, speed):
		while self.idx < len(self.si) and speed >= self.si[self.idx]:
			self.idx += 1
		if self.idx == 0:
			return self.unbal
		return self.ci[self.idx-1] + (speed - self.si[self.idx-1]) * self.mi[self.idx-1]

	def marg_cost(self):
		return 0 if self.idx == 0 else self.mi[self.idx-1]
	
	def next_speed(self):
		return self.si[self.idx] if self.idx < len(self.si) else INF

	def best_cost(self):
		best = self.unbal
		for i in range(len(self.ci)):
			best = min(best, self.ci[i] + (0 if not self.inc else self.si[i] - self.inc.speed))
		return best
	
	def add_segment(self, speed, cost, marg):
		if self.si and self.si[-1] >= speed:
			del self.si[-1:]
			del self.ci[-1:]
			del self.mi[-1:]
		if (marg == 0):
			self.do_add(speed, cost, 0)
			return
		sd = (self.unbal - cost + marg-1) // marg
		if sd <= 0:
			self.do_add(speed, self.unbal, 0)
		else:
			self.do_add(speed, cost, marg)
			self.do_add(speed + sd, self.unbal, 0)
			
	def do_add(self, speed, cost, marg):
		self.si.append(speed)
		self.ci.append(cost)
		self.mi.append(marg)


def godeep(idx):
	cur = graph[idx]
	inc = uplink[idx]
	for e in cur.edges:
		if inc and e.node == inc.prev:
			continue
		uplink[e.node.idx] = e
		stack.append(e.node.idx)


def solve(idx):
	subs = []
	cur = graph[idx]
	inc = uplink[idx]
	mx, sum = 0, 0
	for e in cur.edges:
		mx = max(mx, e.speed)
		if inc and e.node == inc.prev:
			continue
		r = result[e.node.idx]
		subs.append(r)
		sum += r.best_cost()

	result[idx] = SubResult(len(cur.edges), inc, sum)
	s = mx
	while s < INF:
		sc, sm = 0, 0
		for sr in subs:
			sc += sr.cost_for(s) + (s - sr.inc.speed)
			sm += sr.marg_cost() + 1
		result[idx].add_segment(s, sc, sm)
		s = min([INF] + [it.next_speed() for it in subs])


stack = []
n, costsign = [int(f) for f in sys.stdin.readline().split()]
result, uplink = [None] * (n+1), [None] * (n+1)
graph = [Node(i) for i in range(n+1)]
for _ in range(n-1):
	u, v, s = [int(f) for f in sys.stdin.readline().split()]
	graph[u].edges.append(Edge(graph[v], graph[u], s))
	graph[v].edges.append(Edge(graph[u], graph[v], s))

stack.append(1)
visited = set()
while stack:
	idx = stack[-1]
	if idx in visited:
		stack.pop()
		solve(idx)
	else:
		visited.add(idx)
		godeep(idx)
print(result[1].best_cost())

