// A direct translation of the C++ query tree solution.

import java.util.*;
import java.io.*;

public final class onufry_query_tree {
  static int W;
  static int MAXQ;
  static int CMAXQ;
  static double eval;

  static int M;
  static int N;
  static int T;
  static int Q;

  static double[][] probs;
  static double[] evals;
  static double[] tdist;
  static BitSet[] used;
  static BitSet[] disappears;
  static double[][] sdist;
  static double[] mineProbs;
  static double[] Ps;
  static double[] Qs;
  static int[] Ss;

  static void initDist(double dist[]) {
    for (int i = 1; i < W; ++i) dist[i] = 0;
    dist[0] = 1;
  }

  static void addMine(double p, double P[]) {
    double last = P[W-1];
    for (int k = W-1; k > 0; k--) P[k] = (1 - p) * P[k] + p * P[k - 1];
    P[0] = (1 - p) * P[0] + p * last;
  }

  static void pushUsed(int q, int m) {
    int node = q + CMAXQ;
    used[node].set(m, true);
    disappears[node].set(m, false);
    do {
      node = node / 2;
      used[node].set(m, true);
      disappears[node].set(m, false);
      for (int child = 2 * node; child <= 2 * node + 1; ++child) {
        if (!used[child].get(m)) disappears[child].set(m, true);
      }
    } while (node > 1);
  }

  public static void main(String[] args) throws IOException {
    W = 2000;
    MAXQ = 512;
    CMAXQ = 1;
    eval = 0;

    probs = new double[MAXQ * 2 + 1][W];
    evals = new double[MAXQ];
    tdist = new double[W];
    used = new BitSet[MAXQ * 2 + 1];
    disappears = new BitSet[MAXQ * 2 + 1];
    sdist = new double[MAXQ][W];
    mineProbs = new double[MAXQ * MAXQ];
    Ps = new double[MAXQ];
    Qs = new double[MAXQ];
    Ss = new int[MAXQ];

    BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
    String[] ff = in.readLine().split(" ");
    M = Integer.parseInt(ff[0]);
    N = Integer.parseInt(ff[1]);
    T = Integer.parseInt(ff[2]);
    Q = Integer.parseInt(ff[3]);

    while (CMAXQ < Q) CMAXQ *= 2;
    initDist(tdist);
    ff = in.readLine().split(" ");
    for (int i = 0; i < M; ++i) Ps[i] = Double.parseDouble(ff[i]);
    ff = in.readLine().split(" ");
    for (int j = 0; j < N; ++j) Qs[j] = Double.parseDouble(ff[j]);
    for (int i = 0; i < M; ++i) for (int j = 0; j < N; ++j) {
      mineProbs[i + M * j] = Ps[i] + Qs[j];
      addMine(Ps[i] + Qs[j], tdist);
      eval += Ps[i] + Qs[j];
    }
    for (int i = 0; i < MAXQ * 2 + 1; ++i) {
      used[i] = new BitSet(N * M);
      disappears[i] = new BitSet(N * M);
      initDist(probs[i]);
    }
    for (int i = 0; i < MAXQ; ++i) initDist(sdist[i]);
    for (int i = 0; i < M * N; ++i) disappears[1].set(i, true);
    for (int q = 0; q < Q; ++q) {
      ff = in.readLine().split(" ");
      Ss[q] = Integer.parseInt(ff[0]);
      evals[q] = 0;
      for (int ind = 0; ind < Ss[q]; ++ind) {
        int X = Integer.parseInt(ff[2 * ind + 1]) - 1;
        int Y = Integer.parseInt(ff[2 * ind + 2]) - 1;
        int pos = X + M * Y;
        pushUsed(q, pos);
        addMine(mineProbs[pos], sdist[q]);
        evals[q] += mineProbs[pos];
      }
    }
    initDist(probs[0]);
    for (int qnode = 1; qnode < 2 * CMAXQ; ++qnode) {
      System.arraycopy(probs[qnode/2], 0, probs[qnode], 0, W);
      for (int m = 0; m < M * N; ++m) {
        if (disappears[qnode].get(m)) {
          addMine(mineProbs[m], probs[qnode]);
        }
      }
    }
    double norm = tdist[T % W];
    PrintWriter out = new PrintWriter(new BufferedOutputStream(System.out));
    for (int q = 0; q < Q; ++q) {
      for (int s = 0; s <= Ss[q]; ++s) {
        double tsprob = probs[q + CMAXQ][(W + T - s) % W];
        if (s > T || (T - s) < (eval - evals[q]) - W/2 ||
                     (T - s) > (eval - evals[q]) + W/2) {
          tsprob = 0;
        }
        out.print(sdist[q][s] * tsprob / norm);
        out.print(" ");
      }
      out.print("\n");
    }
    out.flush();
  }
}
