/* This is the "Query Tree" approach described here: 
 * https://probo.ecs.baylor.edu/icpc/wf2020/issues/17#note_3894 */

#include <vector>
#include <cstring>
#include <cstdio>

using namespace std;

const int W = 2500;
const int MAXQ = 512;

int CMAXQ = 1; 
// This is the actual size of the array we use.
// This does optimize speed for small Q values (which is irrelevant), and also
// makes debugging easier.

typedef double ld;

ld probs[MAXQ * 2 + 1][W];
ld eval = 0.;
ld evals[MAXQ];
ld tdist[W];
vector<bool> used[MAXQ * 2 + 1];
vector<bool> disappears[MAXQ * 2 + 1];

ld sdist[MAXQ][W];
ld mineProbs[MAXQ * MAXQ];

int M, N, T, Q;

ld Ps[MAXQ];
ld Qs[MAXQ];
int Ss[MAXQ];

void initDist(ld *dist) {
  for (int i = 1; i < W; ++i) dist[i] = 0;
  dist[0] = 1;
}

// The formula is P'(k) = (1-p)P(k) + pP(k-1);
void addMine(ld p, ld *P) {
  ld last = P[W-1];
  for (int k = W-1; k > 0; k--) P[k] = (1-p) * P[k] + p * P[k-1];
  P[0] = (1 - p) * P[0] + p * last;
}

void pushUsed(int q, int m) {
  int node = q + CMAXQ;
  used[node][m] = true;
  disappears[node][m] = false;
  do {
    node = node / 2;
    used[node][m] = true;
    disappears[node][m] = false;
    for (int child = 2 * node; child <= 2 * node + 1; child++) {
      if (!used[child][m]) disappears[child][m] = true;
    }
  } while (node > 1);
}

int main() {
  scanf("%d %d %d %d", &M, &N, &T, &Q);
  while (CMAXQ < Q) CMAXQ *= 2;
  initDist(tdist);
  for (int i = 0; i < M; ++i) scanf("%lf", &Ps[i]);
  for (int j = 0; j < N; ++j) scanf("%lf", &Qs[j]);
  for (int i = 0; i < M; ++i) for (int j = 0; j < N; ++j) {
    mineProbs[i + M * j] = Ps[i] + Qs[j];
    addMine(Ps[i] + Qs[j], tdist);
    eval += Ps[i] + Qs[j];
  }
  for (int i = 0; i < MAXQ * 2 + 1; ++i) {
    used[i].resize(N * M, false);
    disappears[i].resize(N * M, false);
    initDist(probs[i]);
  }
  for (int i = 0; i < MAXQ; ++i) {
    initDist(sdist[i]);
  }
  for (int i = 0; i < M * N; ++i) disappears[1][i] = true;
  for (int q = 0; q < Q; ++q) {
    int S;
    scanf("%d", &S);
    Ss[q] = S;
    evals[q] = 0;
    int X, Y;
    for (int unused = 0; unused < S; ++unused) {
      scanf("%d %d", &X, &Y); X--; Y--;
      int pos = X + M * Y;
      pushUsed(q, pos);
      addMine(mineProbs[pos], sdist[q]);
      evals[q] += mineProbs[pos];
    }
  }
  initDist(probs[0]);
  for (int qnode = 1; qnode < 2 * CMAXQ; ++qnode) {
    memcpy(probs[qnode], probs[qnode/2], W * sizeof(ld));
    for (int m = 0; m < M * N; ++m) {
      if (disappears[qnode][m]) {
        addMine(mineProbs[m], probs[qnode]);
      }
    }
  }
  ld norm = tdist[T % W];
  for (int q = 0; q < Q; ++q) {
    for (int s = 0; s <= Ss[q]; ++s) {
      ld tsprob = probs[q + CMAXQ][(W + T - s) % W];
      if (s > T || (T - s) < (eval - evals[q]) - W/2 ||
                   (T - s) > (eval - evals[q]) + W/2) {
        tsprob = 0;
      }
      printf("%.9lf ", sdist[q][s] * tsprob / norm); 
    }
    printf("\n");
  }
  return 0;
}
