/* Almost naive solution to the Sweep Stakes problem. The only change from
 * running the naive DP is that we try to bound the range on which we run the
 * DP, by saying we ignore anything that's above a certain threshold
 *
 * Now, that's theory. In practice, we can likely afford to be more aggressive,
 * so let's try that :)
 */

// For all complexity calculations, Z = M * N. This algorithm is
// O(Q Z sqrt(Z)).

#include <vector>
#include <cstdio>
#include <utility>
#include <set>
#include <functional>
using namespace std;

typedef double ld;

#define MAXN 500

int M, N, T, Qs;
ld P[MAXN];
ld Q[MAXN];

ld dataT[MAXN * MAXN + 2];
ld dataS[MAXN + 2];
ld dataTS[MAXN * MAXN + 2];

// Fill_data is O(|vs| sqrt(|vs|))
void fill_data(vector<pair<int, int>> vs, ld *data, ld cutoff) {
  data[0] = 1.;
  for (int i = 1; i <= (int) vs.size(); ++i) data[i] = 0;
  int from = 0;
  int to = 0;
  for (auto v : vs) {
    int m = v.first;
    int n = v.second;
    ld prob = P[m] + Q[n];
    for (int v = to + 1; v > from; v--) {
      data[v] = (1. - prob) * data[v] + prob * data[v-1];
    }
    data[from] *= (1. - prob);
    if (data[from] < cutoff) from++;
    if (data[to] >= cutoff) to++;
  }
}

int main() {
  scanf("%d %d %d %d", &M, &N, &T, &Qs);
  for (int m = 0; m < M; m++) scanf("%lf", &P[m]);
  for (int n = 0; n < N; n++) scanf("%lf", &Q[n]);
  vector<pair<int, int>> all;
  for (int m = 0; m < M; ++m) for (int n = 0; n < N; ++n) {
    all.push_back(make_pair(m, n));
  }
  fill_data(all, dataT, 1e-19);
  vector<pair<int, int>> sel;
  set<pair<int, int>> cset;
  for (int q = 0; q < Qs; q++) {
    all.clear();
    sel.clear();
    int S;
    cset.clear();
    scanf("%d", &S);
    for (int s = 0; s < S; ++s) {
      int n, m;
      scanf("%d %d", &m, &n);
      cset.insert(make_pair(m - 1, n - 1));
    }
    for (int m = 0; m < M; m++) for (int n = 0; n < N; n++) {
      auto p = make_pair(m, n);
      if (cset.find(p) == cset.end()) {
        all.push_back(p);
      } else {
        sel.push_back(p);
      }
    }
    fill_data(sel, dataS, 1e-21);
    // This is the dominant factor - for each query, we run filling the 
    // T-S array in O(Z^2).
    fill_data(all, dataTS, 1e-16);
    for (int s = 0; s <= S; ++s) {
      if (s <= T) {
        printf("%.9lf ", dataS[s] * dataTS[T - s] / dataT[T]);
      } else {
        printf("0 ");
      }
    }
    printf("\n");
  }
  return 0;
}
