/* This is the "Convolutional Inverse" approach, described here:
 * https://probo.ecs.baylor.edu/icpc/wf2020/issues/17#note_3986 */

#include <vector>
#include <cstring>
#include <cstdio>
#include <cassert>

using namespace std;

const int W = 2048;
const int MAXQ = 501;
typedef long double ld;

ld XT[W];  // The distribution of T
ld XS[W];  // The distribution of S
ld CF[W];  // The current F function we're convoluting with
ld XTR[W];  // The current T multiplied by Fs so far.
ld XSR[W];  // The current S multiplied by Fs so far
ld NXTR[W];  // The place we accumulate T x F
ld NXSR[W];  // The place we accumulate S x F
ld mineProbs[MAXQ][MAXQ];

int M, N, T, Q;
ld tmp;
ld expected = 0;

// Either pass TO = W-1, or be sure that P[TO] and beyond is zero.
// This is an optimization for the speed of calculating XS.
void addMine(ld *P, ld p, int TO) {
  ld last = P[W-1];
  for (int k = TO; k > 0; k--) P[k] = (1-p) * P[k] + p * P[k-1];
  P[0] = (1 - p) * P[0] + p * last;
}

int main() {
  scanf("%d %d %d %d", &M, &N, &T, &Q);
  for (int i = 0; i < W; ++i) XT[i] = 0;
  XT[0] = 1;
  for (int n = 0; n <= N; ++n) for (int m = 0; m <= M; ++m) mineProbs[m][n] = 0;
  for (int m = 0; m < M; ++m) {
    scanf("%Lf", &tmp);
    for (int n = 0; n < N; ++n) mineProbs[m][n] = tmp;
  }
  for (int n = 0; n < N; ++n) {
    scanf("%Lf", &tmp);
    for (int m = 0; m < M; ++m) {
      mineProbs[m][n] += tmp;
      addMine(XT, mineProbs[m][n], W-1);
      expected += mineProbs[m][n];
    }
  }
  for (int q = 0; q < Q; ++q) {
    ld expected_s = 0;
    for (int i = 0; i < W; ++i) XS[i] = 0;
    XS[0] = 1;
    int S;
    scanf("%d", &S);
    for (int s = 0; s < S; ++s) {
      int X, Y;
      scanf("%d %d", &X, &Y); X--; Y--;
      addMine(XS, mineProbs[X][Y], s+1);
      expected_s += mineProbs[X][Y];
    }
    for (int i = 0; i < W; ++i) {
      XTR[i] = XT[i];
      XSR[i] = XS[i];
    }
    for (int cskip = 1; cskip < W; cskip *= 2) {
      // Define the current F in CF.
      for (int i = 0; i < W; i++) CF[i] = 0;
      for (int i = 0; i < W; i += cskip) {
        CF[i] = XSR[i];
        if (i & cskip) CF[i] *= -1;
      }
      // Multiply both XTR and XSR by CF.
      // For XSR, calculate only the positions divisible by 2*cskip, because
      // the others will be zero by definition.
      for (int i = 0; i < W; i += 2 * cskip) {
        NXSR[i] = 0;
        int cim = i;
        for (int j = 0; j < W; j += cskip) {
          NXSR[i] += XSR[cim] * CF[j];
          cim -= cskip; if (cim < 0) cim += W;
        }
      }
      // For XTR, calculate all positions.
      for (int i = 0; i < W; i++) {
        NXTR[i] = 0;
        int cim = i;
        for (int j = 0; j < W; j += cskip) {
          NXTR[i] += XTR[cim] * CF[j];
          cim -= cskip; if (cim < 0) cim += W;
        }
      }
      // Copy them back.
      for (int i = 0; i < W; ++i) {
        XSR[i] = NXSR[i];
        XTR[i] = NXTR[i];
      }
    }
    for (int s = 0; s <= S; ++s) {
      ld norm = XT[T % W] * XSR[0];
      ld tsprob = XTR[(W + T - s) % W];
      if (s > T || (T - s) < (expected - expected_s) - W/2 ||
                   (T - s) > (expected - expected_s) + W/2) {
        tsprob = 0;
      }
      printf("%.9Lf ", XS[s] * tsprob / norm);
    }
    printf("\n");
  }
  return 0;
}
