#include <bits/stdc++.h>
#include <quadmath.h>

using namespace std;

using real_t = __float128;
using complex_t = complex<real_t>;
static constexpr real_t MTWOPI = -2 * M_PIq;
static constexpr int FFT_SIZE = 16384;

static complex_t make_root(int idx, int len)
{
    real_t angle = MTWOPI * idx / len;
    return complex_t(cosq(angle), sinq(angle));
}

template<typename Traits, typename SizeType = unsigned int>
class FFT
{
public:
    typedef SizeType size_type;
    typedef typename Traits::type type;

private:
    std::vector<std::vector<type>> roots, rroots;
    std::vector<size_type> butterfly;
    type inv_size;

    void permute(std::vector<type> &a) const
    {
        const size_type S = size();
        assert(a.size() == S);
        for (size_type i = 0; i < S; i++)
        {
            size_type other = butterfly[i];
            if (i < other)
                std::swap(a[i], a[other]);
        }
    }

    void transform(std::vector<type> &a, bool invert) const
    {
        const std::vector<std::vector<type>> &allr = invert ? rroots : roots;
        const size_type S = size();

        permute(a);
        for (std::size_t i = 1; i < allr.size(); i++)
        {
            const std::vector<type> &r = allr[i];
            size_type outer = size_type(1) << i;
            size_type inner = outer / 2;
            for (size_type j = 0; j < S; j += outer)
                for (size_type k = 0; k < inner; k++)
                {
                    type x = a[j + k];
                    type y = a[j + k + inner] * r[k];
                    a[j + k] = x + y;
                    a[j + k + inner] = x - y;
                }
        }
    }

    void init_roots(size_type len)
    {
        if (len == 1)
        {
            roots.emplace_back();
            roots.back().push_back(1);
            rroots.push_back(roots.back());
        }
        else
        {
            init_roots(len >> 1);
            std::vector<type> new_roots;
            new_roots.reserve(len);
            for (size_type i = 0; i < len; i++)
                new_roots.push_back(make_root(i, len));
            std::vector<type> new_rroots;
            new_rroots.reserve(len);
            new_rroots.push_back(new_roots[0]);
            new_rroots.insert(new_rroots.end(), new_roots.rbegin(), new_roots.rend() - 1);
            roots.push_back(std::move(new_roots));
            rroots.push_back(std::move(new_rroots));
        }
    }

    void init_butterfly(size_type len)
    {
        butterfly.resize(len);
        for (size_type i = 1; i < len; i <<= 1)
            for (size_type j = 0; j < i; j++)
            {
                butterfly[j] <<= 1;
                butterfly[i + j] = butterfly[j] + 1;
            }
    }

public:
    size_type size() const { return butterfly.size(); }

    FFT(size_type len)
    {
        assert(len > 0 && (len & (len - 1)) == 0);
        init_roots(len);
        init_butterfly(len);
        inv_size = Traits::inverse(len);
    }

    void fft(std::vector<type> &a) const
    {
        transform(a, false);
    }

    void rfft(std::vector<type> &a) const
    {
        transform(a, true);
        for (type &v : a)
            v *= inv_size;
    }
};

template<typename T>
class fft_traits_complex
{
public:
    typedef std::complex<T> type;

    static type inverse(type value)
    {
        return T(1) / value;
    }
};

typedef FFT<fft_traits_complex<real_t>> FFTr;

static inline complex_t cmul(const complex_t &a, const complex_t &b)
{
    return complex_t(a.real() * b.real() - a.imag() * b.imag(),
                     a.real() * b.imag() + a.imag() * b.real());
}

static real_t read_real()
{
    string token;
    cin >> token;
    return strtoflt128(token.c_str(), NULL);
}

int main()
{
    ios::sync_with_stdio(false);
    int R, C, T, Q;
    cin >> R >> C >> T >> Q;
    vector<real_t> pr(R), qc(C);
    for (int i = 0; i < R; i++)
        pr[i] = read_real();
    for (int i = 0; i < C; i++)
        qc[i] = read_real();

    FFTr plan(FFT_SIZE);
    vector<complex_t> prob_f(FFT_SIZE);
    for (int i = 0; i < FFT_SIZE; i++)
        prob_f[i] = make_root(i, FFT_SIZE);

    vector<complex_t> full_f(FFT_SIZE, 1);
    vector<complex_t> row_f(FFT_SIZE);
    real_t expected = 0;
    for (int i = 0; i < R; i++)
    {
        fill(row_f.begin(), row_f.end(), 1);
        for (int j = 0; j < C; j++)
        {
            real_t p = pr[i] + qc[j];
            complex_t q(1 - p, 0);
            for (int k = 0; k < FFT_SIZE; k++)
                row_f[k] = cmul(row_f[k], p * prob_f[k] + q);
            expected += p;
        }
        for (int k = 0; k < FFT_SIZE; k++)
            full_f[k] *= row_f[k];
    }

    vector<complex_t> full = full_f;
    plan.rfft(full);
    assert(fabsq(expected - T) < FFT_SIZE / 2);
    real_t pT = full[T % FFT_SIZE].real();
    assert(pT >= 1e-9);
    real_t norm = 1 / pT;

    cout << fixed << setprecision(12);
    for (int i = 0; i < Q; i++)
    {
        int S;
        cin >> S;
        vector<complex_t> inner(FFT_SIZE, 1);
        real_t qexpected = 0;
        for (int j = 0; j < S; j++)
        {
            int r, c;
            cin >> r >> c;
            r--;
            c--;
            real_t p = pr[r] + qc[c];
            complex_t q(1 - p, 0);
            for (int k = 0; k < FFT_SIZE; k++)
                inner[k] = cmul(inner[k], p * prob_f[k] + q);
            qexpected += p;
        }
        vector<complex_t> outer(FFT_SIZE);
        for (int k = 0; k < FFT_SIZE; k++)
            outer[k] = full_f[k] / inner[k];
        plan.rfft(inner);
        plan.rfft(outer);
        for (int j = 0; j <= S; j++)
        {
            int r = T - j;
            real_t ans = 0;
            if (r >= 0 && r <= R * C - S)
            {
                real_t rexpected = expected - qexpected;
                assert(fabsq(r - rexpected) < FFT_SIZE / 2);
                ans = outer[r % FFT_SIZE].real() * inner[j % FFT_SIZE].real() * norm;
            }
            cout << (long double) ans;
            if (j < S)
                cout << ' ';
        }
        cout << '\n';
    }
}
