#!/usr/bin/env python3


def euclid(a, b):
    """
    Solves ax + by = gcd(a, b)

    returns gcd, x, y
    """
    if b == 0:
        return a, 1, 0
    d, y, x = euclid(b, a % b)

    return d, x, y - (a // b) * x


def inverse(a, m):
    """
    Finds the inverse of a mod m

    Assumes a and m are coprime.
    """
    g, x, y = euclid(a, m)

    assert g == 1

    return x % m


def solve_linear(a, b, m):
    """
    solve ax = b (mod m)

    Always returns nonzero answer. Returns -1 on failure
    """
    assert 0 <= a < m
    assert 0 <= b < m
    if a == 0:
        return 0 if b == 0 else -1

    g, x, y = euclid(a, m)
    if b % g != 0:
        return -1

    a //= g
    b //= g
    m //= g

    res = b * x % m

    return m if res == 0 else res


def main():
    b, d, a = input().split()
    b = int(b)
    d = int(d)

    ans = 0
    if d == 0:
        oldb = b
        p2 = 0
        p5 = 0
        while b % 2 == 0:
            b //= 2
            p2 += 1
        while b % 5 == 0:
            b //= 5
            p5 += 1

        for l in range(len(a) + 1):
            # try l trailing 0s
            base = b * pow(2, max(0, p2 - l)) * pow(5, max(0, p5 - l))
            s = str(base) + ("0" * l)
            if len(s) < len(a) or (len(s) == len(a) and s <= a):
                ans = l
    else:
        p10, v, l = 1 % b, 0, 0
        while l <= len(a):
            if v == 0 and (l < len(a) or str(d) * l <= a):
                # all d
                ans = l

            x = solve_linear(p10, -v % b, b)
            # this is strict, no leading 0s
            if x > 0:
                val = str(x) + (str(d) * l)
                if len(val) < len(a) or (len(val) == len(a) and val <= a):
                    ans = l

            p10 = 10 * p10 % b
            v = (10 * v + d) % b
            l += 1

    print(ans)


if __name__ == "__main__":
    main()
