#!/usr/bin/env python3

import sys

# find a solution of a system of multivariate quadratic equations where
# - no term contains more than one variable
# - all quadratic terms have coefficient 1

eps = 1e-7

# mat = the linear parts of the equations; constants in the last column
d, n = map(int, sys.stdin.readline().split())
inp = [ list(map(float, sys.stdin.readline().split())) for _ in range(n) ]
INP = [ xs[:] for xs in inp ]

p = min(range(n), key=lambda i: inp[i][d])
inp[0], inp[p] = inp[p], inp[0]

trans = inp[0][:]
for i in range(len(inp)):
  for j in range(len(inp[i]) - 1):
    inp[i][j] -= trans[j]
    if abs(inp[i][j]) < eps:
      inp[i][j] = 0

mat = []
for xs in inp:
  ys, e = xs[:-1], xs[-1]
  c = sum(x * x for x in ys) - e * e
  mat.append([ -2 * x for x in ys ] + [c])

# subtracting first equation from the others eliminates their quadratic terms
for i in range(1, n):
  for j in range(d + 1):
    mat[i][j] -= mat[0][j]

# solve system of n-1 linear equations by Gaussian elimination
var = [None]
eq = [None] * d
row, col = 1, 0
while row < n and col < d:
  p = row
  for i in range(p + 1, n):
    if abs(mat[i][col]) > abs(mat[p][col]):
      p = i
  if abs(mat[p][col]) > eps:
    t = mat[row]
    mat[row] = mat[p]
    mat[p] = t
    for i in range(row + 1, n):
      f = mat[i][col] / mat[row][col]
      mat[i][col] = 0
      for j in range(col + 1, d + 1):
        mat[i][j] -= f * mat[row][j]
        if abs(mat[i][j]) < eps:
          mat[i][j] = 0
    var.append(col)
    eq[col] = row
    row += 1
  col += 1
if row < n:
  # assert all(abs(mat[i][d]) < eps for i in range(row, n))
  mat = mat[:row]

# eliminate variables in var; leaves one equation for each depending on other variables
while row > 1:
  row -= 1
  col = var[row]
  assert mat[row][col] != 0
  for i in range(row): # includes row 0, that is, also substitute into first equation
    f = mat[i][col] / mat[row][col]
    mat[i][col] = 0
    for j in range(col + 1, d + 1):
      mat[i][j] -= f * mat[row][j]
      if abs(mat[i][j]) < eps:
        mat[i][j] = 0

compress = [None] * d
decompress = []
cd = 0
for i in range(d):
  if eq[i] == None:
    compress[i] = cd
    decompress.append(i)
    cd += 1

# substitute variables into quadratic part of first equation
quad = [ [0] * cd for _ in range(cd) ]
lin = [ mat[0][j] for j in decompress ] + [ mat[0][d] ]
for i in range(cd):
  quad[i][i] = 1
for di in range(d):
  row = eq[di]
  if row != None:
    for j in range(cd):
      dj = decompress[j]
      for k in range(cd):
        dk = decompress[k]
        quad[min(j, k)][max(j, k)] += mat[row][dj] * mat[row][dk] / (mat[row][di] ** 2)
      lin[j] += 2 * mat[row][dj] * mat[row][d] / (mat[row][di] ** 2)
    lin[cd] += (mat[row][d] / mat[row][di]) ** 2

# find a solution of first equation
def solve(i):
  # consider equation in variable i
  if abs(quad[i][i]) > eps:
    # quadratic equation
    if i + 1 == cd:
      # i is the last variable: solve quadratic equation in i
      disc = lin[i] ** 2 - 4 * quad[i][i] * lin[cd]
      if abs(disc) < eps:
        disc = 0
      assert disc >= 0
      sol = [0] * cd
      sol[i] = (-lin[i] + disc ** 0.5) / (2 * quad[i][i])
      return sol
    # find values for other variables such that discriminant >= 0
    # compute discriminant in quad/lin at indices > i
    for j in range(i + 1, cd):
      for k in range(j, cd):
        quad[j][k] *= -4 * quad[i][i]
    for j in range(i + 1, cd + 1):
      lin[j] *= -4 * quad[i][i]
    for j in range(i + 1, cd):
      for k in range(i + 1, cd):
        quad[min(j, k)][max(j, k)] += quad[i][j] * quad[i][k]
      lin[j] += 2 * quad[i][j] * lin[i]
    lin[cd] += lin[i] ** 2
    # find quadratic term with smallest/largest coefficient
    p = q = i + 1
    for j in range(i + 2, cd):
      if quad[j][j] < quad[p][p]:
        p = j
      if quad[j][j] > quad[q][q]:
        q = j
    if quad[q][q] > eps:
      # quadratic term of q is positive: set all other variables to 0
      sol = [0] * cd
      # set q so that overall discriminant is non-negative
      # overall discriminant is a quadratic function in q with positive quadratic coefficient
      disc = lin[q] ** 2 - 4 * quad[q][q] * lin[cd]
      if disc >= 0:
        # quadratic function has a zero: set q to it
        sol[q] = (-lin[q] + disc ** 0.5) / (2 * quad[q][q])
      else:
        # quadratic function has no zero: it is positive, set q to minimise it
        sol[q] = -lin[q] / (2 * quad[q][q])
      # compute overall discriminant and solve equation for i
      disc = quad[q][q] * (sol[q] ** 2) + lin[q] * sol[q] + lin[cd]
      assert disc >= 0
      sol[i] = (-lin[i] + disc ** 0.5) / (2 * quad[i][i])
      return sol
    if quad[p][p] < -eps or \
       any(abs(lin[j]) > eps for j in range(i + 1, cd)) or \
       any(abs(quad[j][k]) > eps for j in range(i + 1, cd) for k in range(j + 1, cd)):
      # quadratic term of p is negative and all others are non-positive OR
      # there is a linear term with non-zero coefficient OR
      # there is a mixed term with non-zero coefficient:
      # discriminant function is negative far out (in the last two cases, by setting all other variables to 0)
      # since a solution exists, discriminant is positive somewhere
      # hence it must have a zero: find it recursively
      f = abs(4 * quad[i][i])
      for j in range(i + 1, cd):
        for k in range(j, cd):
          quad[j][k] /= f
      for j in range(i + 1, cd + 1):
        lin[j] /= f
      sol = solve(i + 1)
      sol[i] = -(sum(quad[i][j] * sol[j] for j in range(i + 1, cd)) + lin[i]) / (2 * quad[i][i])
      return sol
    # quadratic, linear and mixed terms are all 0, hence discriminant is constant
    assert lin[cd] >= 0
    # any choice of variables gives non-negative discriminant
    sol = [0] * cd
    sol[i] = (-lin[i] + lin[cd] ** 0.5) / (2 * quad[i][i])
    return sol
  if abs(lin[i]) > eps:
    # linear equation: set all other variables to 0
    sol = [0] * cd
    sol[i] = -lin[cd] / lin[i]
    return sol
  # check if a mixed term contains i
  if i + 1 == cd:
    # i is the last variable: constant equation, choose arbitrary value
    assert abs(lin[cd]) < eps
    sol = [0] * cd
    return sol
  p = i + 1
  while p < cd and abs(quad[i][p]) < eps:
    p += 1
  if p == cd:
    # i does not appear in equation: solve recursively, set i arbitrarily
    return solve(i + 1)
  # a mixed term contains i and p: set p to 1 and all other variables to 0
  # solve resulting linear equation in i
  sol = [0] * cd
  sol[p] = 1
  sol[i] = -(lin[p] + lin[cd]) / quad[i][p]
  return sol

sol = [0] * d
if cd > 0:
  csol = solve(0)
  for i, di in enumerate(decompress):
    sol[di] = csol[i]

# calculate values of eliminated variables
for i in range(d):
  if eq[i] != None:
    row = eq[i]
    sol[i] = -(sum(mat[row][j] * sol[j] for j in range(i + 1, d) if eq[j] == None) + mat[row][d]) / mat[row][i]

for i in range(len(sol)):
  sol[i] += trans[i]

for i in range(d):
  print('{:.17f}'.format(sol[i]))

def qd(u):
  return sum(u[i] * u[i] for i in range(len(u)))

def add(u, c, v):
  return [ u[i] + c * v[i] for i in range(len(u)) ]

def abs_or_rel(x, y):
  err = abs(x - y)
  if abs(y) > 1:
    err /= abs(y)
  if err < 1e-5:
    return True
  print(x, y, err)
  return False

for i in range(n):
  abs_or_rel(qd(add(INP[i][:-1], -1, sol)) ** 0.5, INP[i][-1])

