/* Heuristic solution: it has a "current" point, repeatedly picks a
 * flavour vector, and moves the current point halfway towards the
 * point that would make the distance correct (along the line connecting it to
 * the flavour).
 */

#pragma GCC optimize("Ofast")
#pragma GCC target("avx")

#include <bits/stdc++.h>

using namespace std;

static double length(const valarray<double> &x)
{
    return sqrt((x * x).sum());
}

int main()
{
    ios::sync_with_stdio(false);

    int D, N;
    cin >> D >> N;
    vector<valarray<double>> vecs(N, valarray<double>(D));
    vector<double> e(N);
    for (int i = 0; i < N; i++)
    {
        for (int j = 0; j < D; j++)
            cin >> vecs[i][j];
        cin >> e[i];
    }

    minstd_rand engine;
    uniform_real_distribution<double> x_dist(-1000.0, 1000.0);
    uniform_int_distribution<int> v_dist(0, N - 1);
    valarray<double> cur(D);
    for (int i = 0; i < D; i++)
        cur[i] = x_dist(engine);

    for (long pass = 0; ; pass++)
    {
        int v = v_dist(engine);
        double d = length(cur - vecs[v]);
        if (d < 1e-10)
            continue;
        double s = (e[v] + d) / (2 * d);
        cur = vecs[v] + (cur - vecs[v]) * s;

        if (pass % 100003 == 0)
        {
            double err = 0.0;
            for (int i = 0; i < N; i++)
            {
                double d = length(cur - vecs[i]);
                err = max(err, fabs(d - e[i]) / max(1.0, e[i]));
            }
            if (err < 1e-5)
                break;
        }
        if (N <= 4 && pass >= 10000000) // to pass the samples
        {
            for (int i = 0; i < D; i++)
                cur[i] = x_dist(engine);
            pass = 0;
        }
    }

    cout << fixed << setprecision(17);
    for (int i = 0; i < D; i++)
        cout << cur[i] << ' ';
    cout << '\n';
}
