import argparse
import random
import sys
random.seed(2019)

parser = argparse.ArgumentParser()
parser.add_argument('N')
parser.add_argument('--mode', default='RANDOM')
args = parser.parse_args()

data = []

def Letter():
  return "ACGT"[random.randint(0, 3)]

def Random(N):
  for x in range(N):
    data.append(Letter())

def OneLetter(N):
  letter = Letter()
  for _ in range(N):
    data.append(letter)

def AddSymmetries(N, sym_size, sym_len):
  for _ in range(sym_size):
    curstart = len(data) - 1
    for i in range(curstart, curstart - sym_len, -1):
      if len(data) == N:
        return
      data.append(data[i])

def Symmetries(N, mins, maxs):
  seed_size = min(N // 100, 10)
  seed_size = max(seed_size, 3)
  seed_size = min(seed_size, N)
  Random(seed_size)
  while len(data) < N:
    if random.randint(0, 1):
      data.reverse()
    AddSymmetries(N, random.randint(mins, maxs),
            random.randint(len(data) // 2, len(data)))

def MostlySymmetries(N):
  while len(data) < N:
    if random.randint(0, 1):
      data.reverse()
    to_add = min(N - len(data), random.randint(1, 4))
    Random(to_add)
    AddSymmetries(N, random.randint(2, 3),
            random.randint(len(data) // 2, len(data)))

def _ThueMorseSeq(N):
  seq = [0]
  b = 1
  for i in range(1, N):
    while 2*b <= i: b *= 2
    seq.append(seq[i-b] ^ 1)
  return seq

def ThueMorse(N):
  syms = list('ACGT')
  random.shuffle(syms)
  seq = _ThueMorseSeq(N)
  data.append(syms[2])
  for i in range(N):
    data.append(syms[seq[i]])
  data.append(syms[2])

def ThueMorseRep(N):
  syms = list('ACGT')
  random.shuffle(syms)
  seq = [2] + _ThueMorseSeq(128) + [2]
  reps = (N-2*len(seq))//(2*len(seq))
  for _ in range(reps):
    data.extend([syms[x] for x in seq])
  seq.reverse()
  data.extend([syms[x] for x in seq])
  seq.reverse()
  data.extend([syms[x] for x in seq])
  seq.reverse()
  for _ in range(reps):
    data.extend([syms[x] for x in seq])

def AntiQuadratic1(N):
  M = (N - 4) // 4
  data.extend(['AG' * M, 'CTCT', 'GA' * M])

def AntiQuadratic2(N):
  syms = list('ACGT')
  random.shuffle(syms)
  data.append(syms[0])
  for i in range(N-2):
    data.append(syms[1])
  data.append(syms[2])

def AntiQuadratic3(N):
  syms = list('ACGT')
  random.shuffle(syms)
  M = (N-1)//3
  for i in range(M):
    data.append(syms[i%2])
  for i in range(M):
    data.append(syms[2])
  data.append(syms[3])
  for i in range(M):
    data.append(syms[(i%2)^(M%2)^1])

def AntiQuadratic4(N):
  syms = list('ACGT')
  random.shuffle(syms)
  M = (N-101)//3
  for i in range(M+100):
    data.append(syms[i%2])
  for i in range(M):
    data.append(syms[2])
  data.append(syms[2])
  for i in range(M):
    data.append(syms[(i%2)^(M%2)^1])



N = int(args.N)
mode = args.mode.upper()
if mode == 'RANDOM':
  Random(N)
elif mode == 'ONELETTER':
  OneLetter(N)
elif mode == 'TWOSYMMETRIES':
  Symmetries(N, 2, 2)
elif mode == 'FEWSYMMETRIES':
  Symmetries(N, 2, 3)
elif mode == 'MANYSYMMETRIES':
  Symmetries(N, 2, 10)
elif mode == 'MOSTLYSYMMETRIES':
  MostlySymmetries(N)
elif mode == 'THUEMORSE':
  ThueMorse(N)
elif mode == 'THUEMORSEREP':
  ThueMorseRep(N)
elif mode == 'ANTIQUADRATIC1':
  AntiQuadratic1(N)
elif mode == 'ANTIQUADRATIC2':
  AntiQuadratic2(N)
elif mode == 'ANTIQUADRATIC3':
  AntiQuadratic3(N)
elif mode == 'ANTIQUADRATIC4':
  AntiQuadratic4(N)
else:
  print('Invalid mode: %s' % args.mode)
  sys.exit(1)
print(''.join(data))
